define(["jquery", "theme_boost/drawers", "format_levels/slick"], (function($, Drawers) {

    var element = document.querySelector('#course-section-levels.section-slide');

    const singleSection = document.getElementsByClassName('single-section');

    const isSectionPage = (singleSection.length > 0);

    const touchDevice = (navigator.maxTouchPoints || 'ontouchstart' in document.documentElement);

    const levelsFormat = () => {
        // Add student-view body class.
        document.body.classList.add('student-view');

        if (element != undefined) {
            initCarousel();
        }
        // Update the restriction as tooltip.
        updateRestrictionTooltip();
        // Add animation to display the activity.
        addActivityAnimation();

        // Hide the page loader once the content load completed.
        setTimeout(() => {
            hideLoader();
        }, "1000");
    };

    /**
     * Hide the page loader.
     */
    const hideLoader = function() {
        var loader = document.getElementById('format-levels-loader');
        if (loader) {
            var style = window.getComputedStyle(loader);
            if (style) {
                if (style.display != 'none') {
                    loader.style.visibility = "hidden";
                    loader.remove();
                }
            }
        }
    };

    /**
     * Verify the given element in the viewport.
     *
     * @param {HTMLElement} el Element to verify
     * @returns {bool}
     */
    const inView = function(el) {
        const rect = el.getBoundingClientRect();
        return (
            rect.top >= 0 &&
            rect.left >= 0 &&
            rect.bottom <= (window.innerHeight || document.documentElement.clientHeight) &&
            rect.right <= (window.innerWidth || document.documentElement.clientWidth)

        );
    };

    /**
     * Initialize the carousel for sections in course homepage.
     * @returns {bool}
     */
    const initCarousel = function() {

        if ($(element).find("li.section").length <= 1) {
            return null;
        }
        var slidesToShow = $(element).find("li.section").length <= 4
            ? $(element).find("li.section").length : 5;

        $(element).slick({
            centerMode: true,
            variableHeight: true,
            slidesToShow: slidesToShow,
            infinite: true,
            dots: false,
            autoplay: true,
            autoplaySpeed: 2000,
            initialSlide: $(element).find('.slick-current').length > 0 && $(element).find("li.section").length > slidesToShow
            ? parseInt($(element).find('.slick-current').index()) : 0,
            responsive: [
                {
                    breakpoint: 1400,
                    settings: {
                        centerMode: true,
                        centerPadding: '40px',
                        slidesToShow: 3,
                        initialSlide: $(element).find('.slick-current').length > 0 && $(element).find("li.section").length > 3
                        ? parseInt($(element).find('.slick-current').index()) : 0,
                    }
                },
                {
                    breakpoint: 767,
                    settings: {
                        centerMode: true,
                        centerPadding: '40px',
                        slidesToShow: 2,
                        initialSlide: $(element).find('.slick-current').length > 0 && $(element).find("li.section").length > 2
                        ? parseInt($(element).find('.slick-current').index()) : 0,
                    }
                },
                {
                    breakpoint: 480,
                    settings: {
                        arrows: false,
                        centerMode: true,
                        centerPadding: '40px',
                        slidesToShow: 1,
                        initialSlide: $(element).find('.slick-current').length > 0 && $(element).find("li.section").length > 1
                        ? parseInt($(element).find('.slick-current').index()) : 0,
                    }
                }
            ]
        });
        return true;
    };

    /**
     * Update the restriction info to html data title atttribute this will renderer by BS tooltip js.
     */
    const updateRestrictionTooltip = () => {
        document.querySelectorAll('.format-levels .restriction-block').forEach(function(e) {
            if (document.querySelector(e.getAttribute('data-selector')) != undefined) {
                e.setAttribute('title', document.querySelector(e.getAttribute('data-selector')).innerHTML);
            }
        });

        $('[data-toggle="tooltip-manual"]').tooltip({
            trigger: 'manual',
            html: true,
            title: function() {
                var title = $(this).attr('title') || $(this).attr('data-title');
                $(this).attr('data-title', title);
                $(this).attr('title', '');
                return $(this).attr('data-title');
            }
        });

        $('[data-toggle="tooltip-manual"]').on('mouseover', function() {
            if ($(this).is(':visible')) {
                $(this).tooltip('show');
            }
        });

        $('[data-toggle="tooltip-manual"]').on('mouseleave', function() {
            if (!$('.tooltip:hover').length) {
                $('.tooltip').tooltip('hide');
            } else {
                $('.tooltip:hover').mouseleave(function() {
                    $(this).tooltip('hide');
                });
            }
        });

        $('[data-tooltip-onclick="hide"]').on('click', function() {
            var elem = $(this);
            setTimeout(function() {
                elem.tooltip('hide');
            }, 300);
        });
    };

    /**
     * Attach the animation class to the activity elements initialy activities are in hidden state.
     * Adding animation classes will reveal the activities to users.
     * Used for hide the image flickers during the pageload.
     */
    const addActivityAnimation = () => {
        if (isSectionPage) {
            if (touchDevice) {
                window.onscroll = function() {
                    updateActiveState();
                };
            }
        }
    };

    const updateActiveState = () => {
        document.querySelectorAll('.format-levels-studentview .section li.activity .has-active-image').forEach(function(elem) {
            if (inView(elem)) {
                elem.querySelector('.activitylevelimage').style.display = 'none';
                elem.querySelector('.activity-active-image').style.display = 'block';
            } else {
                elem.querySelector('.activity-active-image').style.display = 'none';
                elem.querySelector('.activitylevelimage').style.display = 'block';
            }
        });
    };

    return {
        init: function() {
            levelsFormat();

            // Setup fixed position to fix drawers position clitch.
            document.addEventListener(Drawers.eventTypes.drawerShow, e => {
                e.target.style.position = 'fixed';
            });
            // Fix for right drawer on shown in initial pageload.
            if (document.querySelector('.drawer-right') != undefined) {
                var rightDrawer = document.querySelector('.drawer-right');
                rightDrawer.style.position = 'fixed';
            }
        },
        hideLoader: hideLoader
    };
}));

// # sourceMappingURL=levels.min.js.map
