define(['jquery', 'core/dragdrop', 'core/fragment', 'format_levels/levels'], function($, dragDrop, Fragment, Levels) {

    const modSelector = 'ul.section li.activity';

    let sectionElem, bgImage, originalHeight, originalWidth;

    var list = {};

    const pageElem = () => document.getElementById('page');

    const modules = () => document.querySelectorAll(modSelector);

    const resizePosition = (setup = false) => {

        sectionElem = document.querySelector('.levelmap-img');
        if (document.querySelector('.levelmap-img') != undefined) {
            bgImage = fetchBackground();
            bgImage.onload = () => {
                findBGSize();
                setOriginalMode();
                if (setup) {
                    setupDrag();
                    document.body.classList.add('setup-module-position');
                } else {
                    // Timeout to load the images when the popupformat update the content takes time to load image height and width.
                    delayedSetupPositions();
                    window.addEventListener('resize', () => setSelectedMode());
                    pageElem().addEventListener('resize', () => setSelectedMode());
                }
            };
        }

    };

    /**
     * Verify the module images are loaded and then retrieve the module sizes
     * it will prevent the size issue in fit height and fit width when the popup format loads the content after closing any modal.
     */
    const delayedSetupPositions = () => {
        var mods = modules();
        var isLoaded, img;
        var delay = false;
        if (mods.length > 0) {
            mods.forEach((mod) => {
                img = mod.querySelector('img');
                isLoaded = img == undefined || (img.complete && img.naturalHeight !== 0);
                if (!isLoaded) {
                    delay = true;
                }
            });
        }
        if (!delay) {
            fetchModPositions();
            if (setSelectedMode()) {
                setTimeout(() => Levels.hideLoader(), 600);
            }
        } else {
            setTimeout(function() {
                delayedSetupPositions();
            }, 100);
        }
    };

    const setupDrag = ()=>{
        $('li.activity').on('mousedown', function(e) {
            e.preventDefault();
            dragDrop.prepare(e);
            dragDrop.start(e, $(this), function() {
                void (0);
            }, function(x, y, dragged) {
                if (dragged.length <= 0) {
                    return;
                }

                var params = {x: dragged[0].style.left, y: dragged[0].style.top, modid: dragged[0].dataset.id};
                var contexts = Array.from(document.body.classList).filter(word => word.startsWith('context-'));
                if (contexts.length > 0) {
                    var contextid = contexts[0].replace('context-', '');
                    Fragment.loadFragment('format_levels', 'update_mod_positions', contextid, params);
                }
            });
        });
        $('li.activity').on('click', function(e) {
            e.preventDefault();
        });
    };

    const fetchBackground = ()=>{
        var imageSrc = sectionElem.dataset.sectionimage;
        var image = new Image();
        image.src = imageSrc;
        image.style.position = 'absolute';
        image.id = 'levels-course-background';
        return image;
    };

    const findBGSize = ()=>{
        originalWidth = parseInt(sectionElem.dataset.width) || bgImage.width;
        originalHeight = parseInt(sectionElem.dataset.height) || bgImage.height;
    };

    const setOriginalMode = ()=>{
        pageElem().style.minWidth = originalWidth ? originalWidth + 'px' : 'auto';
        pageElem().style.minHeight = originalHeight ? originalHeight + 'px' : 'auto';
    };

    const fetchModPositions = ()=>{
        var mods = modules();

        if (mods.length > 0) {
            mods.forEach((mod) => {
                var imgs = mod.querySelectorAll('img');
                var images = [];
                imgs.forEach((img) => {
                    images.push({height: img.height, width: img.width});
                });
                list[mod.dataset.id] = {left: parseInt(mod.style.left), top: parseInt(mod.style.top), images: images};
            });
        }
    };

    const findNewHeight = () => {
        var newWidth = pageElem().clientWidth;
        return (originalHeight / originalWidth) * newWidth;
    };

    const findNewWidth = () => {
        var newHeight = pageElem().clientHeight;
        return (originalWidth / originalHeight) * newHeight;
    };

    const removeCourseBG = function() {
        if (document.getElementById('levels-course-background') != undefined) {
            document.getElementById('levels-course-background').remove();
        }
    };

    const setPageSize = ()=>{

        pageElem().style.minHeight = '';
        pageElem().style.minWidth = '';

        if (sectionElem.classList.contains('mapsize-fitwidth')) {
            var height = findNewHeight();
            pageElem().style.height = height ? height + 'px' : 'auto';
            bgImage.style.height = height + 'px';
            bgImage.style.width = '100%';
            bgImage.style.left = '0';
            bgImage.style.top = '0';
            bgImage.style.visibility = 'hidden';
            removeCourseBG();
            $("#page").prepend(bgImage);
        } else if (sectionElem.classList.contains('mapsize-fitheight')) {
            var width = findNewWidth();
            pageElem().style.width = width ? width + 'px' : 'auto';
            bgImage.style.width = width + 'px';
            bgImage.style.height = '100%';
            bgImage.style.top = '0';
            bgImage.style.left = '0';
            bgImage.style.visibility = 'hidden';
            removeCourseBG();
            $("#page").prepend(bgImage);
        } else if (sectionElem.classList.contains('mapsize-original')) {
            pageElem().style.minHeight = originalHeight ? originalHeight + 'px' : 'auto';
            pageElem().style.minWidth = originalWidth ? originalWidth + 'px' : 'auto';
        }
    };

    const setSelectedMode = ()=>{
        setPageSize();
        var bgHeightRatio, bgWidthRatio;
        if (sectionElem.classList.contains('mapsize-fitwidth')) {
            bgWidthRatio = originalWidth / pageElem().clientWidth;
            bgHeightRatio = originalHeight / findNewHeight();
        } else if (sectionElem.classList.contains('mapsize-fitheight')) {
            bgWidthRatio = originalWidth / findNewWidth();
            bgHeightRatio = originalHeight / pageElem().clientHeight;
        } else {
            bgWidthRatio = originalWidth / pageElem().clientWidth;
            bgHeightRatio = originalHeight / pageElem().clientHeight;
        }
        var moduleStyle;
        for (var key in list) {
            moduleStyle = list[key];
            var left = moduleStyle.left / bgWidthRatio;
            var top = moduleStyle.top / bgHeightRatio;
            var mod = document.querySelector('li.activity[data-id="' + key + '"]');
            mod.style.top = top + 'px';
            mod.style.left = left + 'px';
            var imgs = mod.querySelectorAll('img');
            let images = moduleStyle.images;
            imgs.forEach((img, num) => {
                if (num in images) {
                    if (images[num].width / bgWidthRatio > 0) {
                        img.width = images[num].width / bgWidthRatio;
                    }
                    if (images[num].height / bgHeightRatio > 0) {
                        img.height = images[num].height / bgHeightRatio;
                    }
                }
            });
        }
        return true;
    };

    return {
        resizePosition: resizePosition
    };
});
