<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Levels course format. Display the sections as carousel and moduels in level map view.
 *
 * @package   format_levels
 * @copyright 2022 bdecent gmbh <https://bdecent.de>
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

require_once($CFG->libdir.'/filelib.php');
require_once($CFG->libdir.'/completionlib.php');

// Horrible backwards compatible parameter aliasing.
if ($level = optional_param('level', 0, PARAM_INT)) {
    $url = $PAGE->url;
    $url->param('section', $level);
    debugging('Outdated level param passed to course/view.php', DEBUG_DEVELOPER);
    redirect($url);
}
// End backwards-compatible aliasing.

// Retrieve course format option fields and add them to the $course object.
$format = course_get_format($course);
$course = $format->get_course();
// Make sure section 0 is created.
course_create_sections_if_missing($format->get_course(), 0);

global $PAGE;
$PAGE->set_secondary_navigation(false);

$renderer = $PAGE->get_renderer('format_levels');

if (!empty($displaysection)) {
    if (method_exists($format, 'set_sectionnum')) {
        $format->set_sectionnum($displaysection);
    } else {
        $format->set_section_number($displaysection);
    }
}

$outputclass = $format->get_output_classname('content');
$output = new $outputclass($format);
echo $renderer->render($output);


$ispopupactivities = isset($course->popupactivities) && $course->popupactivities;
$setup = (optional_param('setup', 0, PARAM_BOOL) && has_capability('format/levels:managelevels', $PAGE->context));
if ($ispopupactivities && !$PAGE->user_is_editing() && !empty($displaysection) && !$setup) {
    // Include popups.
    $PAGE->requires->js_call_amd('format_popups/popups', 'init', [
        $context->id, $course->id, $displaysection,
    ]);
}
