<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Global settings page.
 *
 * @package   format_levels
 * @copyright 2022 bdecent gmbh <https://bdecent.de>
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die;

require_once($CFG->dirroot."/course/format/levels/lib.php");


if ($ADMIN->fulltree) {
    $settingspage = new theme_boost_admin_settingspage_tabs('formatsettinglevels', get_string('configtitle', 'format_levels'));

    $settings = new admin_settingpage('format_levels_defaults', get_string('defaults', 'format_levels'));

    $settings->add(
        new admin_setting_configselect('format_levels/initialposition',
        new lang_string('initialposition', 'format_levels'),
        new lang_string('initialposition_desc', 'format_levels'),
        'lefttop',
        [
            'lefttop' => new lang_string('lefttop', 'format_levels'),
            'leftcenter' => new lang_string('leftcenter', 'format_levels'),
            'leftbottom' => new lang_string('leftbottom', 'format_levels'),
            'righttop' => new lang_string('righttop', 'format_levels'),
            'rightbottom' => new lang_string('rightbottom', 'format_levels'),
            'rightcenter' => new lang_string('rightcenter', 'format_levels'),
            'centerbottom' => new lang_string('centerbottom', 'format_levels'),
            'centertop' => new lang_string('centertop', 'format_levels'),
            'centercenter' => new lang_string('centercenter', 'format_levels'),
        ]
        )
    );

    $settings->add(
        new admin_setting_configselect('format_levels/levelmapsize',
        new lang_string('levelmapsize', 'format_levels'),
        new lang_string('levelmapsize_desc', 'format_levels'),
        'fitheight',
        [
            'original' => new lang_string('originalsize', 'format_levels'),
            'fitheight' => new lang_string('fitheight', 'format_levels'),
            'fitwidth' => new lang_string('fitwidth', 'format_levels'),
        ]
        )
    );

    $settings->add(
        new admin_setting_configselect('format_levels/courseindex',
            new lang_string('courseindex', 'format_levels'),
            new lang_string('courseindex_desc', 'format_levels'),
            \format_levels::HIDE_EVERYWHERE,
            [
                0 => new lang_string('show'),
                \format_levels::HIDE_ON_COURSEPAGE => new lang_string('hideoncourses', 'format_levels'),
                \format_levels::HIDE_EVERYWHERE => new lang_string('hideeverywhere', 'format_levels'),
            ],
        )
    );

    $settings->add(
        new admin_setting_configselect('format_levels/popupactivities',
            new lang_string('popupactivities', 'format_levels'),
            new lang_string('popupactivities_desc', 'format_levels'),
            LEVELS_DISABLE_POPUPACTIVITIES,
            [
                LEVELS_DISABLE_POPUPACTIVITIES => new lang_string('disable'),
                LEVELS_ENABLE_POPUPACTIVITIES => new lang_string('enable'),
            ],
        )
    );

    $settings->add(
        new admin_setting_configcheckbox('format_levels/useactivityimages',
            new lang_string('useactivityimages', 'format_levels'),
            new lang_string('useactivityimages_desc', 'format_levels'),
            1
        )
    );

    $settingspage->add($settings);

    $settings = new admin_settingpage('format_levels_settingstab', get_string('settingstab', 'format_levels'));

    $settings->add(
        new admin_setting_configtext('format_levels/activityimgsize',
        new lang_string('activityimgsize', 'format_levels'),
        new lang_string('activityimgsize_desc', 'format_levels'),
        '500 kb'
        )
    );



    $settings->add(
        new admin_setting_configtext('format_levels/sectionimgsize',
        new lang_string('sectionimgsize', 'format_levels'),
        new lang_string('sectionimgsize_desc', 'format_levels'),
        '1 mb'
        )
    );

    $settings->add(
        new admin_setting_configtext('format_levels/courseimgsize',
        new lang_string('courseimgsize', 'format_levels'),
        new lang_string('courseimgsize_desc', 'format_levels'),
        '1 mb'
        )
    );

    $settings->add(
        new admin_setting_configtext('format_levels/backgroundwidth',
        new lang_string('backgroundwidth', 'format_levels'),
        new lang_string('backgroundwidth_desc', 'format_levels'),
        '', PARAM_INT)
    );

    $settings->add(
        new admin_setting_configtext('format_levels/backgroundheight',
        new lang_string('backgroundheight', 'format_levels'),
        new lang_string('backgroundheight_desc', 'format_levels'),
        '', PARAM_INT)
    );

    $settings->add(
        new admin_setting_configtext('format_levels/imgwidth',
        new lang_string('imgwidth', 'format_levels'),
        new lang_string('imgwidth_desc', 'format_levels'),
        '300', PARAM_INT)
    );

    $settings->add(
        new admin_setting_configtext('format_levels/imgheight',
        new lang_string('imgheight', 'format_levels'),
        new lang_string('imgheight_desc', 'format_levels'),
        '300', PARAM_INT)
    );

    $settings->add(
        new admin_setting_configselect('format_levels/objectposition',
            new lang_string('objectposition', 'format_levels'),
            new lang_string('objectposition_help', 'format_levels'),
            \format_levels::OBJECTTOP,
            [
                \format_levels::OBJECTTOP => new lang_string('objecttop', 'format_levels'),
                \format_levels::OBJECTRIGHT => new lang_string('objectright', 'format_levels'),
                \format_levels::OBJECTBOTTOM => new lang_string('objectbottom', 'format_levels'),
                \format_levels::OBJECTLEFT => new lang_string('objectleft', 'format_levels'),
            ],
        )
    );

    $settingspage->add($settings);

    $settings = $settingspage;

    $settings = new admin_settingpage('format_levels_fallbackimg', get_string('fallbackimg', 'format_levels'));

    $settings->add(
        new admin_setting_configstoredfile('format_levels/courselevelbg',
        new lang_string('courselevelbg', 'format_levels'),
        new lang_string('courselevelbg_desc', 'format_levels'),
        'courselevelbg'
        )
    );

    $settings->add(
        new admin_setting_configstoredfile('format_levels/sectionavailablelevelbg',
        new lang_string('sectionavailablelevelbg', 'format_levels'),
        new lang_string('sectionavailablelevelbg_desc', 'format_levels'),
        'sectionavailablelevelbg'
        )
    );

    $settings->add(
        new admin_setting_configstoredfile('format_levels/sectionunavailablelevelbg',
        new lang_string('sectionunavailablelevelbg', 'format_levels'),
        new lang_string('sectionunavailablelevelbg_desc', 'format_levels'),
        'sectionunavailablelevelbg'
        )
    );

    $settings->add(
        new admin_setting_configstoredfile('format_levels/sectioncompletelevelbg',
        new lang_string('sectioncompletelevelbg', 'format_levels'),
        new lang_string('sectioncompletelevelbg_desc', 'format_levels'),
        'sectioncompletelevelbg'
        )
    );

    $settings->add(
        new admin_setting_configstoredfile('format_levels/sectionpreviewlevelbg',
        new lang_string('sectionpreviewlevelbg', 'format_levels'),
        new lang_string('sectionpreviewlevelbg_desc', 'format_levels'),
        'sectionpreviewlevelbg'
        )
    );


    $settings->add(
        new admin_setting_configstoredfile('format_levels/modavailablelevelbg',
        new lang_string('modavailablelevelbg', 'format_levels'),
        new lang_string('modavailablelevelbg_desc', 'format_levels'),
        'modavailablelevelbg'
        )
    );

    $settings->add(
        new admin_setting_configstoredfile('format_levels/modnextavailablelevelbg',
        new lang_string('modnextavailablelevelbg', 'format_levels'),
        new lang_string('modnextavailablelevelbg_desc', 'format_levels'),
        'modnextavailablelevelbg'
        )
    );

    $settings->add(
        new admin_setting_configstoredfile('format_levels/modunavailablelevelbg',
        new lang_string('modunavailablelevelbg', 'format_levels'),
        new lang_string('modunavailablelevelbg_desc', 'format_levels'),
        'modunavailablelevelbg'
        )
    );


    $settings->add(
        new admin_setting_configstoredfile('format_levels/modcompletelevelbg',
        new lang_string('modcompletelevelbg', 'format_levels'),
        new lang_string('modcompletelevelbg', 'format_levels'),
        'modcompletelevelbg'
        )
    );

    $settings->add(
        new admin_setting_configstoredfile('format_levels/modactivebg',
        new lang_string('modactivebg', 'format_levels'),
        new lang_string('modactivebg_desc', 'format_levels'),
        'modactivebg'
        )
    );

    $settingspage->add($settings);
    $settings = $settingspage;

}
