<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Behat Designer course format steps definitions.
 *
 * @package    format_levels
 * @category   test
 * @copyright  2020 bdecent gmbh <https://bdecent.de>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once(__DIR__ . '/../../../../../lib/behat/behat_base.php');

use Behat\Mink\Exception\ExpectationException as ExpectationException;

/**
 * Designer course format steps definitions.
 *
 * @package    format_levels
 * @category   test
 * @copyright  2021 bdecent gmbh <https://bdecent.de>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class behat_format_levels extends behat_base {

    /**
     * Go to editing section layout for specified section number and layout type.
     * You need to be in the course page and on editing mode.
     *
     * @Given /^I check coursebg "(?P<str1>(?:[^"]|\\")*)" must contain "(?P<str2>(?:[^"]|\\")*)" "(?P<str3>(?:[^"]|\\")*)"$/
     * @param string $selector
     * @param string $courseshortname
     * @param string $filename
     *
     */
    public function i_check_course_bg_image($selector, $courseshortname, $filename) {
        global $DB, $CFG;
        $course = $DB->get_record('course', ['shortname' => $courseshortname]);
        $context = \context_course::instance($course->id);
        $imageurl = "url(\"".$CFG->wwwroot."/pluginfile.php/". $context->id ."/format_levels/coursebgimage/0/"
            .$filename."\")";
        $stylejs = "
            return (
                Y.one('{$selector}').getComputedStyle('background-image')
            )
        ";
        if ($this->evaluate_script($stylejs) != $imageurl) {
            throw new ExpectationException("Doesn't working correct background style", $this->getSession());
        }
    }

    /**
     * Go to editing section layout for specified section number and layout type.
     * You need to be in the course page and on editing mode.
     *
     * @Given /^I sectionbg "(?P<str>(?:[^"]|\\")*)" "(?P<str2>(?:[^"]|\\")*)" "(?P<str3>(?:[^"]|\\")*)" "(?P<str4>(?:[^"]|\\")*)"$/
     * @param string $selector
     * @param string $courseshortname
     * @param string $filename
     * @param string $filearea
     */
    public function i_check_section_bg_image($selector, $courseshortname, $filename, $filearea) {
        global $DB, $CFG;
        $course = $DB->get_record('course', ['shortname' => $courseshortname]);
        $context = \context_course::instance($course->id);
        $section = $DB->get_record('course_sections', ['section' => 1, 'course' => $course->id]);
        $imageurl = "url(\"".$CFG->wwwroot."/pluginfile.php/". $context->id ."/format_levels/".
            $filearea."/".$section->id."/".$filename."\")";
        $stylejs = "
            return (
                Y.one('{$selector}').getComputedStyle('background-image')
            )
        ";
        if ($this->evaluate_script($stylejs) != $imageurl) {
            throw new ExpectationException("Doesn't working correct background style", $this->getSession());
        }
    }

    /**
     * Checks if the tile photo is set to a certain value
     *
     * @Given :arg1 should contain style :arg2 :arg3
     * @throws \Behat\Mink\Exception\ElementNotFoundException Thrown by behat_base::find
     * @throws \Behat\Mink\Exception\ExpectationException
     * @param string $selector
     * @param string $style
     * @param string $value
     * @return string The style of the image container
     */
    public function should_contain_style($selector, $style, $value) {
        $stylejs = "
            return (
                Y.one('{$selector}').getComputedStyle('$style')
            )
        ";
        if ($this->evaluate_script($stylejs) != $value) {
            throw new ExpectationException("Doesn't working correct levels style", $this->getSession());
        }
    }

    /**
     * Checks if the tile photo is set to a certain value
     *
     * @Given :arg1 should contain not style :arg2 :arg3
     * @throws \Behat\Mink\Exception\ElementNotFoundException Thrown by behat_base::find
     * @throws \Behat\Mink\Exception\ExpectationException
     * @param string $selector
     * @param string $style
     * @param string $value
     * @return string The style of the image container
     */
    public function should_not_contain_style($selector, $style, $value) {
        $stylejs = "
            return (
                Y.one('{$selector}').getComputedStyle('$style')
            )
        ";
        if ($this->evaluate_script($stylejs) == $value) {
            throw new ExpectationException("Doesn't working correct levels style", $this->getSession());
        }
    }
}
