// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Defines Kicstart pro javascript.
 * @module    local_kickstart_pro/kickstartcourseformat
 * @category  Classes - autoloading
 * @copyright 2021, bdecent gmbh bdecent.de
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
define([], function() {

    /**
     * Controls kicstart pro javascript.
     * @param {string} editicon
     */
    var Kickstartcourseformat = function(editicon) {
        var shortInput = document.querySelector(this.shortnameSelector);
        if (shortInput) {
            shortInput.insertAdjacentHTML("afterend", editicon);
        }
        document.querySelector(this.shortnameSelector).disabled = true;
        document.querySelector(this.fullnameSelector).addEventListener("focusout", this.autoShortname.bind(this), false);
        document.querySelector(this.editicon).addEventListener('click', this.enableEditshortname.bind(this));
    };
    Kickstartcourseformat.prototype.fullnameSelector = "#page-content form input[name='fullname']";
    Kickstartcourseformat.prototype.shortnameSelector = "#page-content form input[name='shortname']";
    Kickstartcourseformat.prototype.courseForm = "#page-content form";
    Kickstartcourseformat.prototype.editicon = "#page-content form .shortname-editform";

    Kickstartcourseformat.prototype.autoShortname = function() {
        var formElement = document.querySelectorAll(this.courseForm)[0];
        var formData = new FormData(formElement);
        var fullName = formData.get('fullname');
        document.querySelector(this.shortnameSelector).value = fullName;
    };

    Kickstartcourseformat.prototype.enableEditshortname = function() {
        var shortNameAction = document.querySelector(this.shortnameSelector);
        shortNameAction.disabled = false;
        shortNameAction.select();
    };

    return {
        init: function(editicon) {
            return new Kickstartcourseformat(editicon);
        }
    };
});