<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Course creation form.
 *
 * @package    local_kickstart_pro
 * @copyright  2019 bdecent gmbh <https://bdecent.de>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace local_kickstart_pro\form;

use html_writer;

defined('MOODLE_INTERNAL') || die();

require_once("$CFG->libdir/formslib.php");
/**
 * Create course form.
 */
class course_form extends \moodleform {

    /**
     * Add elements to form
     */
    protected function definition() {
        global $CFG, $OUTPUT;

        $mform = $this->_form;
        $categoryid = $this->_customdata['categoryid'];
        $creatorinstrctionshtml = get_config('format_kickstart', 'coursecreatorinstructions');
        $creatorinfo = html_writer::start_tag('div', array('id' => "fitem_id_creatorinfo", 'class' => "form-group row fitem"));
        $creatorinfo .= html_writer::tag('div', $creatorinstrctionshtml, array('id' => 'coursecreator-instractions'));
        $creatorinfo .= html_writer::end_tag('div');
        $mform->addElement('html', $creatorinfo);

        $mform->addElement('text', 'fullname', get_string('fullnamecourse'), 'maxlength="100" size="50"');
        $mform->addHelpButton('fullname', 'fullnamecourse');
        $mform->addRule('fullname', get_string('missingfullname'), 'required', null, 'client');
        $mform->setType('fullname', PARAM_TEXT);

        $mform->addElement('text', 'shortname', get_string('shortname', 'format_kickstart'),
        'maxlength ="100" size = "20"');
        $mform->setType('shortname', PARAM_TEXT);

        $categoryslist = \core_course_category::make_categories_list('moodle/course:create');
        $categorybase = '';
        if (count($categoryslist) > 1) {
            $categorybase = 'multiple';
            $strselectcate = array(get_string('selectcategory', 'format_kickstart'));
            $displaylist = $strselectcate + $categoryslist;
        }

        if ($categorybase == 'multiple') {
            $mform->addElement('select', 'category', get_string('coursecategory'), $displaylist);
            if ($categoryid) {
                $mform->setDefault('category', $categoryid);
            }
            $mform->addHelpButton('category', 'coursecategory');
            $mform->addRule('category', get_string('missingcategory', 'format_kickstart'), 'required', null, 'client');
        } else {
            $mform->addElement('text', 'categoryfield', get_string('coursecategory'), 'maxlength="254" size="50" disabled');
            $mform->addHelpButton('categoryfield', 'coursecategory');
            $categoryname = implode("", $categoryslist);
            $mform->setDefault('categoryfield', $categoryname);
            $mform->setType('categoryfield', PARAM_TEXT);

            $mform->addElement('hidden', 'category', array_search($categoryname, $categoryslist));
            $mform->setType('category', PARAM_INT);
        }
        $this->add_action_buttons(true, get_string('continue'));
    }

    /**
     * Custom form validation
     * @param  array $data
     * @param  array $files
     * @return array List of errors.
     */
    public function validation($data, $files) {
        $errors = [];
        if (empty($data['category'])) {
            $errors['category'] = get_string('missingcategory', 'format_kickstart');
        }
        return $errors;
    }
}
