<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Create a Kickstart pro templates.
 *
 * @package    local_kickstart_pro
 * @copyright  2021 bdecent gmbh <https://bdecent.de>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

require(__DIR__."/protemplates.php");
/**
 * Install the Kickstart pro templates
 */
function install_pro_templates() {
    global $protemplates, $DB, $CFG;
    if (file_exists($CFG->dirroot.'/course/format/kickstart/lib.php')) {
        require_once($CFG->dirroot.'/course/format/kickstart/lib.php');
    }
    $context = context_system::instance();
    $listtemplates = $DB->count_records('format_kickstart_template');
    $cnt = $listtemplates + 1;
    if (!empty($protemplates)) {
        $templates = [];
        foreach ($protemplates as $template) {
            $template = (object) $template;
            // Create template.
            $templateid = format_kickstart_create_template($template, $cnt, $context, 'local_kickstart_pro');
            $cnt++;
            $templates[] = $templateid;
        }
        $templatesinfo = array_merge(explode(",", $CFG->kickstart_templates), $templates);
        set_config('kickstart_templates', implode(',', $templatesinfo));
    }
}

