<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Local Reset - User choice responses reset structures defined.
 *
 * @package    local_reset
 * @copyright  2024 LMSACE DEV
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace local_reset\plugins;

use moodle_exception;

/**
 * Process the reset of choice responses from the choice module.
 */
class mod_choice {

    /**
     * Include the choice lib and intiate the reset process of choice responses.
     *
     * @param stdclass $data
     * @return void
     */
    public static function reset_user_attempt($data) {
        global $CFG;

        if (file_exists($CFG->dirroot.'/mod/choice/lib.php')) {
            require_once($CFG->dirroot.'/mod/choice/lib.php');

            return (new self())->reset_choice((object) $data);
        }

        return false;
    }

    /**
     * Reset the choice responses for the given user in all choice instance form the course.
     *
     * @param stdclass $data
     * @return void
     */
    protected function reset_choice($data) {
        global $CFG, $DB;

        $status = false;

        try {
            $transaction = $DB->start_delegated_transaction();

            // Remove choice responses.
            $DB->delete_records_select('choice_answers',
                "userid = ? and choiceid IN (SELECT id FROM {choice} WHERE course = ?)", [$data->userid, $data->courseid]);

            $transaction->allow_commit();

            $status = true;

        } catch (moodle_exception $e) {

            $transaction->rollback($e);
        }

        return $status;
    }
}
