<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Local Reset - H5pactivity module reset structures defined.
 *
 * @package    local_reset
 * @copyright  2024 LMSACE DEV
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace local_reset\plugins;

/**
 * Process the reset of user attempts from the h5pactivity module.
 */
class mod_h5pactivity {


    /**
     * Include the h5pactivity lib and intiate the reset process of h5pactivity attempts.
     *
     * @param stdclass $data
     * @return void
     */
    public static function reset_user_attempt($data) {
        global $CFG;

        if (file_exists($CFG->dirroot.'/mod/h5pactivity/lib.php')) {
            require_once($CFG->dirroot.'/mod/h5pactivity/lib.php');

            return (new self())->reset_h5pactivity((object) $data);
        }

        return false;
    }


    /**
     * Reset the h5pactivity attempts for the given user in all h5pactivity instance form the course.
     *
     * @param stdclass $data
     * @return void
     */
    protected function reset_h5pactivity($data) {
        global $DB, $CFG;

        $status = false;

        try {

            $params = ['courseid' => $data->courseid];
            $sql = "SELECT a.id FROM {h5pactivity} a WHERE a.course=:courseid";
            if ($activities = $DB->get_records_sql($sql, $params)) {
                foreach ($activities as $activity) {
                    $cm = get_coursemodule_from_instance('h5pactivity',
                                                         $activity->id,
                                                         $data->courseid,
                                                         false,
                                                         MUST_EXIST);
                    $user = $DB->get_record('user', ['id' => $data->userid]);
                    // Removes all h5pactivity attempts.
                    \mod_h5pactivity\local\attempt::delete_all_attempts($cm, $user);
                }
            }

            h5pactivity_reset_gradebook($data->courseid, 'reset');

            $status = true;

        } catch (\moodle_exception $e) {

            $transaction->rollback($e);

        }

        return $status;
    }

}