<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Local Reset - Scorm module attempt reset structures defined.
 *
 * @package    local_reset
 * @copyright  2024 LMSACE DEV
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace local_reset\plugins;

/**
 * Process the reset of user attempts from the scorm module.
 */
class mod_scorm {

    /**
     * Include the scorm lib and intiate the reset process of scorm attempts.
     *
     * @param stdclass $data
     * @return void
     */
    public static function reset_user_attempt($data) {
        global $CFG;

        if (file_exists($CFG->dirroot.'/mod/scorm/lib.php')) {

            require_once($CFG->dirroot.'/mod/scorm/lib.php');

            return (new self())->reset_scorm((object) $data);
        }

        return false;
    }

    /**
     * Reset the user attempt for the given user in all scorm instance form the course.
     *
     * @param stdclass $data
     * @return void
     */
    protected function reset_scorm($data) {
        global $DB, $CFG;

        require_once($CFG->dirroot.'/mod/scorm/locallib.php');

        $status = false;

        try {
            $transaction = $DB->start_delegated_transaction();

            $scorms = $DB->get_recordset('scorm', ['course' => $data->courseid]);
            foreach ($scorms as $scorm) {
                scorm_delete_tracks($scorm->id, null, $data->userid);
            }
            $scorms->close();

            // Remove all grades from gradebook.
            scorm_reset_gradebook($data->courseid);

            // Allow the DB transactions to commit to the DB.
            $transaction->allow_commit();

            $status = true;

        } catch (\moodle_exception $e) {

            $transaction->rollback($e);

        }

        return $status;
    }
}
