<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Local Reset Libarary - Functions to extend moodle callbacks are defined.
 *
 * @package    local_reset
 * @copyright  2024 LMSACE DEV
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die;

/**
 * Extend the course secondary navigation to include the reset participants link for users with reset capability.
 *
 * @param navigation $navigation
 * @param stdclass $course
 * @param \context $context
 * @return void
 */
function local_reset_extend_navigation_course($navigation, $course, $context) {

    // Include the link to access the customized participants list with reset option.
    if (has_capability('local/reset:resetuserattempts', $context)) {
        $url = new moodle_url('/local/reset/index.php', ['id' => $course->id]);
        $name = get_string('pluginname', 'local_reset');
        $navigation->add($name, $url, navigation_node::TYPE_SETTING, null, null, new pix_icon('i/settings', ''));
    }
}
