<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Local Reset - Process the reset of selected user attempts.
 *
 * @package    local_reset
 * @copyright  2024 LMSACE DEV
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once('../../config.php');

require_login();

$id = required_param('id', PARAM_INT);
$userid = required_param('user', PARAM_INT);

// Verify the course exists.
$course = $DB->get_record('course', array('id' => $id), '*', MUST_EXIST);

$context = context_course::instance($course->id, MUST_EXIST);

// Verify the current user has capability to reset user attempts.
require_capability('local/reset:resetuserattempts', $context);

// ...Setup the page details.
$url = new moodle_url('/local/reset/reset.php', ['id' => $id, 'user' => $userid]);
$PAGE->set_url($url);
$PAGE->set_context($context);
$PAGE->set_title(get_string('reset', 'core'));
$PAGE->set_heading(format_string($course->fullname).'-'.get_string('reset', 'core'));

// Verify the user enrolment in enabled.
if (!\local_reset\table\participants::has_user_enrolment($userid, $course, $context)) {
    throw new moodle_exception('usernothaveenrolmentmethod', 'local_reset');
}

// Create reset instance for the course.
$reset = local_reset\reset::instance($course);

// Initiate the reset of user attempts.
if ($status = $reset->reset($userid)) {
    // Create the notification for the reset success.
    core\notification::success(get_string('resetsuccess', 'local_reset'));
} else {
    core\notification::error(get_string('resetfailed', 'local_reset'));
}

// Redirect to the participants list page.
redirect(new moodle_url('/local/reset/index.php', ['id' => $id]));
