define(['jquery', 'mod_contentdesigner/elements', 'core/ajax', 'core/fragment',
    'core/templates', 'core/loadingicon', 'core/notification', 'core/str'],
    function ($, Elements, AJAX, Fragment, Templates, LoadingIcon, Notification, Str) {

        const chapterCTA = 'button.complete-chapter';

        const progressBar = 'div#contentdesigner-progressbar';

        let completionIcon, completionStr;

        var chapterInProgress = false;

        const initEventListeners = () => {
            Templates.renderPix('e/tick', 'core').done(function (img) {
                completionIcon = img;
            });
            Str.get_string('completion_manual:done', 'course').done((str) => {
                completionStr = str;
            });
            // Remove previous eventlisteners on body. to support popup format.
            document.body.removeEventListener('click', completeChapterListener);
            document.body.addEventListener('click', completeChapterListener);

            automaticCompletion();

            document.querySelector('#page').addEventListener('scroll', () => {
                automaticCompletion();
                stickyProgress();
            });

            window.addEventListener('scroll', () => {
                automaticCompletion();
                stickyProgress();
            });
        };

        const completeChapterListener = (e) => {
            var completeCTA = e.target.closest(chapterCTA);
            if (completeCTA != undefined) {
                e.preventDefault();
                var chapter = completeCTA.dataset.chapterid;
                var promise = completeChapter(chapter, completeCTA);
                promise.done(() => {
                    updateProgress();
                    completeCTA.classList.remove('btn-outline-secondary');
                    completeCTA.classList.add('btn-success');
                    completeCTA.innerHTML = completionIcon + ' ' + completionStr;
                    Elements.removeWarning();
                    Elements.refreshContent();
                    // TODO: Add a additional function to support loadnext chapter works like replaceonrefresh.
                    // Until hide this loadNextchapters().
                    // Elements.loadNextChapters(chapter);
                }).catch(Notification.exception);
            }
        };

        const stickyProgress = function () {
            var progressElem = document.querySelector('.contentdesigner-progress');
            var contentWrapper = document.querySelector('.contentdesigner-content');
            if (contentWrapper != undefined && contentWrapper.getBoundingClientRect().top < 50) {
                contentWrapper.classList.add('sticky-progress');
                progressElem.classList.add('fixed-top');
            } else {
                progressElem.classList.remove('fixed-top');
                contentWrapper.classList.remove('sticky-progress');
            }
        };

        const completeChapter = (chapter, button) => {
            var promises = AJAX.call([{
                methodname: 'element_chapter_update_completion',
                args: {
                    chapter: chapter,
                    cmid: Elements.contentDesignerData().cmid
                }
            }]);
            LoadingIcon.addIconToContainerRemoveOnCompletion(button, promises[0]);

            return promises[0];
        };

        const updateProgress = () => {
            var params = { cmid: Elements.contentDesignerData().cmid };
            Fragment.loadFragment('element_chapter', 'update_progressbar', Elements.contentDesignerData().contextid, params).done((html, js) => {
                Templates.replaceNode(progressBar, html, js);
            }).catch(Notification.exception);
        };

        /**
         * Automatically completes the current chapter when it becomes visible.
         */
        const automaticCompletion = () => {
            // Select all chapters with completion mode set to auto.
            const chapters = Array.from(
                document.querySelectorAll('.course-content-list .chapters-list[data-completionmode="1"]')
            );

            // Return if no chapters are found or if an AJAX request is already in progress.
            if (!chapters.length || chapterInProgress) {
                return;
            }

            // Loop through the chapters.
            for (let i = 0; i < chapters.length; i++) {
                const currentChapter = chapters[i];

                // Skip if the current chapter is already completed.
                if (currentChapter.classList.contains('completed')) {
                    continue;
                }

                // Check if the current chapter is in the viewport.
                if (isElementInViewport(currentChapter)) {
                    chapterInProgress = true;
                    const chapterId = currentChapter.dataset.id;
                    completion(currentChapter, chapterId);
                }
            }
        };

        const completion = (currentChapter, chapterId) => {
            // AJAX call to complete the current chapter when the next one enters the viewport
            AJAX.call([{
                methodname: 'element_chapter_update_completion',
                args: {
                    chapter: chapterId,
                    cmid: Elements.contentDesignerData().cmid
                }
            }])[0].done(() => {
                currentChapter.classList.add('completed');  // Mark as completed
                updateProgress();
                Elements.removeWarning();
                Elements.refreshContent();
                currentChapter.removeEventListener('scroll', automaticCompletion);
            }).always(() => {
                chapterInProgress = false;
            }).catch(Notification.exception);

        };

        const isElementInViewport = (el) => {
            // Helper function to check if an element is visible in the viewport.
            const rect = el.getBoundingClientRect();
            return (
                rect.top < (window.innerHeight || document.documentElement.clientHeight) &&
                rect.bottom > 0 &&
                rect.left < (window.innerWidth || document.documentElement.clientWidth) &&
                rect.right > 0
            );
        };

        return {
            init: function () {
                initEventListeners();
            },
        };
    });
