define(['jquery', 'core/ajax', 'mod_contentdesigner/elements', 'core/notification', 'core/fragment', 'core/templates'],
    function ($, Ajax, Elements, notification, Fragment, Templates) {

        /**
         * Initialize the poll element results.
         */
        const initpoll = () => {
            // If there's a restriction on the number of options, limit the selections.
            var chapters = document.querySelectorAll('.contentdesigner-content .course-content-list .chapters-list');
            chapters.forEach((chapter) => {
                var polls = chapter.querySelectorAll('.element-item .poll-section');
                polls.forEach((poll) => {
                    var maxselection = poll.dataset.selectcount;
                    var updaterating = poll.dataset.updaterating;
                    var checkboxes = poll.querySelectorAll('input[name="answer[]"]');
                    if (updaterating == 1) {
                        checkboxes.forEach((checkbox) => {
                            checkbox.addEventListener('change', function () {
                                var checkedcount = poll.querySelectorAll('input[name="answer[]"]:checked').length;
                                if (checkedcount >= maxselection && maxselection >= 1) {
                                    checkboxes.forEach(function (box) {
                                        if (!box.checked) {
                                            box.disabled = true;
                                        }
                                    });
                                } else {
                                    checkboxes.forEach(function (box) {
                                        box.disabled = false;
                                    });
                                }
                            });
                        });
                    } else {
                        checkboxes.forEach(function (box) {
                            box.disabled = false;
                        });
                    }

                    var submitbtn = poll.querySelector('form .submit');
                    submitbtn.addEventListener('click', () => {
                        // Collect checked option values.
                        var optionids = [];
                        var checkedboxes = poll.querySelectorAll('input[name="answer[]"]:checked, input[name="answer"]:checked');
                        checkedboxes.forEach(function (checkbox) {
                            optionids.push(checkbox.value);
                        });

                        var chartarea = poll.nextElementSibling;

                        Ajax.call([{
                            methodname: 'element_poll_store_poll_result',
                            args: {
                                optionids: optionids, // Options ID.
                                pollid: parseInt(poll.dataset.pollid), // Poll ID.
                                instanceid: parseInt(poll.dataset.instanceid), // Content designer ID.
                            },
                            done: function (response) {

                                if (response) {
                                    var args = {
                                        cmid: Elements.contentDesignerData().cmid,
                                        pollid: parseInt(poll.dataset.pollid), // Poll ID.
                                    };

                                    Fragment.loadFragment('element_poll', 'update_pollchart',
                                        Elements.contentDesignerData().contextid, args).done((html, js) => {
                                            Templates.replaceNodeContents(chartarea, html, js);
                                        }).catch(notification.exception);

                                    var checkboxes = poll.querySelectorAll('input[name="answer[]"], input[name="answer"]');

                                    if (updaterating != 1) {
                                        poll.querySelector('.submit').disabled = true;
                                        checkboxes.forEach((checkbox) => {
                                            checkbox.disabled = true;
                                        });
                                    } else {
                                        poll.querySelector('.submit').disabled = false;
                                        checkboxes.forEach(function (checkbox) {
                                            var checkedcount = poll.querySelectorAll('input[name="answer[]"]:checked').length;
                                            if (checkedcount >= maxselection && maxselection >= 1) {
                                                if (!checkbox.checked) {
                                                    checkbox.disabled = true;
                                                }
                                            }
                                        });
                                    }

                                    Elements.removeWarning();
                                    Elements.refreshContent();
                                    return;
                                }
                            }
                        }]);
                    });
                });
            });
        };


        return {
            init: function () {
                initpoll();
            }
        };
    });