<?php

namespace element_question;

use stdClass;
use question_engine;
use question_usage_by_activity;
use context_module;
use question_display_options;

class attempt {

    protected int $cmid;

    protected int $instanceid;

    protected stdClass $instance;

    protected int $userid;

    protected question_usage_by_activity $quba;

    protected int $slot;

    protected \context_module $context;

    protected display_options $options;

    protected helper $helper;

    public function __construct(int $cmid, int $instanceid, ?stdClass $instance=null, ?int $userid=null) {
        global $USER;

        // Course module id.
        $this->cmid = $cmid;

        $this->context = context_module::instance($cmid);

        // Instance id.
        $this->instanceid = $instanceid;

        $this->instance = $instance ?: $this->get_instancedata();

        // print_r($this->instance);

        // Current element instance.
        // $this->instance = (object) $instance ?: new stdClass();

        $this->userid = $userid ?: $USER->id;

        $this->options = new display_options($this->instance->behaviour ?? '');

        // echo 'test';
        // print_r($this->instance); // ->contentdesignerid;
        $this->helper = \element_question\helper::instance($this->instance->contentdesignerid);
    }

    protected function get_instancedata() : stdClass {

        $element = \mod_contentdesigner\editor::get_element(\element_question\element::SHORTNAME, $this->cmid);
        $instance = $element->get_instance($this->instanceid, true);
        return (object) $instance;
    }

    public function start_new_attempt() {
        // TODO: In upcoming version, if need to manage attempts like quiz. The attempt verification script goes here.

        // TODO: Update the maxmark and variant : Important.
        $variant = $this->instance->questionversion;

        // Start new attempt.
        if (empty($this->quba)) {
            $this->create_new_usage(); // Create a new usage.
        }

        $maxmark = 1;
        $question = \question_bank::load_question($this->instance->questionid);
        $this->slot = $this->quba->add_question($question, $maxmark);

        $this->quba->start_question($this->slot, $variant);
        // TODO: Update the log of content designer to start of new attempt.
        $this->save_usage();
        // Update the new usage.
        $this->helper->update_new_usage($this->quba->get_id(), $this->userid, $this->instanceid, $this->slot);
    }

    protected function continue_last_attempt($attempt) {
        global $CFG;

        require_once($CFG->dirroot.'/question/engine/questionattempt.php');

        // Load the question usage.
        $this->load_question_usage($attempt->uniqueid);

        $slots = $attempt->slots ? json_decode($attempt->slots, true) : [];
        $slot = $slots[$this->instanceid] ?? 0;

        if ($slot) {
            $this->slot = $slot;

            $question = $this->quba->get_question($slot);
            if ($question->id !== $this->instance->questionid) {
                $maxmark = 1;
                $question = \question_bank::load_question($this->instance->questionid);
                $this->quba->add_question_in_place_of_other($slot, $question, $maxmark);
                $this->quba->start_question($this->slot, $this->instance->questionversion);

            }
            // $this->quba->start_question($slot);
        } else {
            $this->start_new_attempt();
        }
        // $this->helper->update_new_usage($this->quba->get_id(), $this->userid, $this->instanceid, $this->slot);
    }

    protected function load_question_usage(int $qubaid) {
        global $DB;
        $this->quba = question_engine::load_questions_usage_by_activity($qubaid, $DB);
    }

    public function create_new_usage() {
        $this->quba = question_engine::make_questions_usage_by_activity('element_question', $this->context);
        $this->quba->set_preferred_behaviour($this->options->behaviour);
        $this->save_usage();

    }

    /**
     * Save the usage.
     *
     * @return void
     */
    protected function save_usage() {
        // Save the question usage.
        \question_engine::save_questions_usage_by_activity($this->quba);
    }

    /**
     * Load the question slot.
     *
     * @param [type] $attempt
     * @return void
     */
    protected function load_question_slot($attempt) {
        $slots = $attempt->slots ? json_decode($attempt->slots, true) : [];
        $slot = $slots[$this->instanceid] ?? 0;

        if ($slot) {
            $this->slot = $slot;
        }
    }

    /**
     * Process submitted data.
     *
     * @param stdClass $submitteddata
     * @return void
     */
    public function process_submitted_data($submitteddata) {
        $attempt = $this->helper->find_usage($this->userid);
        if (!empty($attempt->uniqueid)) {
            $this->load_question_usage($attempt->uniqueid);
            $this->load_question_slot($attempt);

            // print_r($submitteddata);
            $this->quba->process_all_actions(null, (array) $submitteddata);
            $this->save_usage();
        }
    }

    /**
     * Finish question.
     *
     * @return void
     */
    public function finish_question() {
        $this->quba->finish_question($this->slot);
        $this->save_usage();
    }

    /**
     * Render attempt.
     *
     * @return void
     */
    public function render_attempt() {
        global $PAGE;

        if ($attempt = $this->helper->find_usage($this->userid)) {
            // $this->load_question_usage($qubaid);
            $this->continue_last_attempt($attempt);
            $state = $this->quba->get_question_state($this->slot, false);
            // print_obj($state::class);exit;
            $isfinished = str_contains($state::class, 'question_state_graded') ? true : false;
        } else {
            $this->start_new_attempt();
        }

        $PAGE->requires->js_module('core_question_engine');

        $this->quba->render_question_head_html($this->slot);

        $questionoutput = $this->quba->render_question($this->slot, $this->options, $displaynumber ?? 1);

        $customdata = [
            'cmid' => $this->cmid,
            'contentdesignerid' => $this->instance->contentdesignerid ?? 0,
            'instanceid' => $this->instanceid ?? 1,
            'behavior' => $this->instance->behaviour ?? $this->options->behaviour,
            'questionoutput' => $questionoutput,
            'questionid' => $this->instance->questionid,
            'slot' => $this->slot,
            'finished' => $isfinished ?? false,
        ];

        $questionform = new question_form(null, $customdata, 'get');

        return $questionform->render();
    }


        /**
     * Wrapper round print_question from lib/questionlib.php.
     *
     * @param int $slot the id of a question in this quiz attempt.
     * @return string HTML of the question.
     */
    public function render_attempt_for_commenting() {

        $this->options->generalfeedback = question_display_options::HIDDEN;
        $this->options->manualcomment = question_display_options::EDITABLE;

        return $this->quba->render_question($this->slot, $this->options, $this->instance->title);
    }
}
