<?php

namespace element_question;

require_once($CFG->libdir . '/formslib.php');

use moodle_url;
use moodleform;

class question_form extends \core_form\dynamic_form {

    /**
     * Content form elements defined.
     *
     * @return void
     */
    public function definition() {
        $mform = $this->_form;

        // $this->_customdata['forceuniqueid'] = 'finishquestion';

        $mform->updateAttributes(['id' => 'responseform', 'class' => 'mform element-question-form responseform']);

        $mform->addElement('hidden', 'questionid', $this->_customdata['questionid'] ?? 0);
        $mform->setType('questionid', PARAM_INT);

        $mform->addElement('hidden',  'slots',  $this->_customdata['slot'] ?? 1);
        $mform->setType('slots', PARAM_INT);

        // // Cmid.
        // $mform->addElement('hidden', 'id', $this->_customdata['contentinstanceid']);
        // $mform->setType('id', PARAM_INT);

        // cmid
        $mform->addElement('hidden', 'cmid', $this->_customdata['cmid']);
        $mform->setType('cmid', PARAM_INT);

        // Instance id
        $mform->addElement('hidden', 'id', $this->_customdata['instanceid']);
        $mform->setType('id', PARAM_INT);

        // Finish attempt.
        $mform->addElement('hidden', 'finishattempt', 0);
        $mform->setType('finishattempt', PARAM_INT);

        // print_obj($this->_customdata);
        $mform->addElement('html', $this->_customdata['questionoutput']);

        // Is the question attempt finished.
        if (empty($this->_customdata['finished'])) {
            $this->add_action_buttons(false, get_string('finish', 'contentdesigner'));
        }
    }

    /**
     * Get the context related to this form.
     */
    protected function get_context_for_dynamic_submission(): \context {
        // Block record id.
        $cmid = $this->optional_param('cmid', 0, PARAM_INT);

        return $cmid ? \context_module::instance($cmid) : \context_system::instance();
    }

    /**
     */
    protected function check_access_for_dynamic_submission(): void {
        // Validatation of user capability goes here.
    }

    /**
     * Process the submission from AJAX.
     *
     * @return void
     */
    public function process_dynamic_submission() {
        global $DB;

        // Get the submitted content data.
        $formdata = (object) fix_utf8($this->_ajaxformdata);

        $cmid = $formdata->cmid;
        $instanceid = $formdata->id;

        $attempt = new attempt($cmid, $instanceid);
        $attempt->process_submitted_data($formdata);

        if ($formdata->finishattempt) {
            $attempt->finish_question();
        }
    }

     /**
     * Return submitted data if properly submitted or returns NULL if validation fails or
     * if there is no submitted data.
     *
     * note: $slashed param removed
     *
     * @return stdClass|null submitted data; NULL if not valid or not submitted or cancelled
     */
   /*  function get_data() {
        $mform =& $this->_form;

        if (!$this->is_cancelled() and $this->is_submitted() and $this->is_validated()) {

            $elementlist = array_keys($this->_ajaxformdata);

            $data = $mform->exportValues($elementlist);
            unset($data['sesskey']); // we do not need to return sesskey
            unset($data['_qf__'.$this->_formname]);   // we do not need the submission marker too
            if (empty($data)) {
                return NULL;
            } else {
                return (object)$data;
            }
        } else {
            return NULL;
        }
    } */

    /**
     *
     * @return void
     */
    public function set_data_for_dynamic_submission(): void {
        // global $DB;

        $cmid = $this->optional_param('cmid', 0, PARAM_INT);
        $instanceid = $this->optional_param('instanceid', 0, PARAM_INT);

        $defaults = [
            'cmid' => $cmid,
            'instanceid' => $instanceid,
        ];

        /* if ($blockid) {
            // Fetch the stored config options for this block using block_instance.
            $blockinstance = $DB->get_record('block_instances', ['id' => $blockid]);
            $block = block_instance($blockinstance->blockname, $blockinstance);
            if (!empty($block->config)) {
                $config = (array) clone($block->config);
                $defaults = array_merge($defaults, $config); // Merge the preferences with default values.
                if (isset($defaults['preferences']['content_preferences'][$layoutid])) {
                    $contentpreference = $defaults['preferences']['content_preferences'][$layoutid];
                    $defaults['content_preferences'] = (array) $contentpreference; // Setup default preference.
                }
            }
        } */

        // Setup the block config data to form.
        $this->set_data($defaults);
    }

    /**
     * Get the page ulr to submittit the form data.
     */
    protected function get_page_url_for_dynamic_submission(): moodle_url {
        return new \moodle_url('/local/dash/content/contentform.php', []);
    }

    /**
     * Fetch the widget form elemants.
     *
     * @return \MoodleQuickForm
     */
    public function get_form() {
        return $this->_form;
    }
}
