
import {loadFragment} from 'core/fragment';
import Templates from 'core/templates';
import {getString} from 'core/str';
import * as LoadingIcon from 'core/loadingicon';
import * as Notification from 'core/notification';
import * as FilterEvents from 'core_filters/events';


const SELECTORS = {
    choiceCard: '.qtype-imagechoice .answers .card',
    answerRadio: 'input.qtype-imagechoice-answer-radio',
    answerCheckbox: 'input[type=checkbox].answer-radio',
    submitRadio: 'input[type=radio][name$=submit]',
    responseForm: 'form#responseform',
    fieldset: 'fieldset.qtype-imagechoice',
    answers: '.answers',
    selectedAnswer: '.selected-answer',
    card: '.card',
    other: {
        selectedAnswer: 'selected-answer',
        feedbackListen: 'imagechoice-feedback-listen',
    },
    feedbackAudio: '.selected-answer .specificfeedback audio',
    feedbackText: '.selected-answer .specificfeedback',
    nextButton: '.submitbtns .btn',
    multiAnswerSubmit: '.btn.qtype_imagechoice-mutisubmit',
    error: '.formulation .qtype-imagechoice-error',
};

var contextID = null;
var options = null;
var errorMsg = null;
const forceFeedback = {
    none: 0,
    audio: 1,
    duration: 2,
};


class ImageChoiceQuestionType {

    /**
     *
     * @param {int} questionDivID
     * @param {int} contextid
     * @param {array} option
     */
    constructor(questionDivID, contextid, option) {
        // Set global contextid.
        contextID = contextid;
        options = option;

        this.options = option;
        this.options.forcenext = parseInt(this.options.forcenext);
        this.options.forcefeedback = parseInt(this.options.forcefeedback);
        this.options.feedbackduration = parseInt(this.options.feedbackduration);

        this.contextID = contextid;
        this.questionDivID = questionDivID;
        this.uniqueID = '#' + questionDivID;
        this.root = this.getRoot();
        this.responseForm = this.getResponseForm();

        this.ispreview = this.root.querySelector(SELECTORS.fieldset).dataset.ispreview == 'true';
        this.previewid = false;

        if (this.ispreview) {
            var params = new URLSearchParams(this.responseForm.action);
            this.previewid = params.get('previewid');
        }

        this.addAnwerSelection();

        getString('selectanswererror', 'qtype_imagechoice').then((str) => {
            var span = document.createElement('span');
            span.innerText = str;
            span.classList.add('qtype-imagechoice-error');
            span.classList.add('text-danger');
            span.classList.add('warning');
            errorMsg = span;
        }).catch(Notification.exception);
    }


    getRoot() {
        return document.querySelector("#" + this.questionDivID);
    }

    getCards() {
        return document.querySelectorAll("#" + this.questionDivID + " " + SELECTORS.choiceCard);
    }

    getResponseForm() {
        return document.querySelector(SELECTORS.responseForm);
    }

    showError() {
        this.root.querySelector('.formulation').appendChild(errorMsg);
    }

    hideError() {
        if (this.root.querySelector(SELECTORS.error) !== null) {
            this.root.querySelector(SELECTORS.error).remove();
        }
    }

    /**
     * Not used anymore. remove this.
     */
    removeAudioSkin() {
        // Remove the media plugin js class to rempve the skill of audio players.
        var audios = this.getRoot().querySelectorAll('.specificfeedback .mediaplugin_videojs');
        audios === null || audios.forEach(e => {
            // e.classList.remove('mediaplugin_videojs');

            var audio = e.querySelector('audio.video-js').cloneNode(true);
            audio.classList.remove('video-js');

            e.querySelector('audio.video-js').closest('.specificfeedback').append(audio);

            e.querySelector('audio.video-js').remove();
            e.remove();
            // .classList.remove('video-js');
        });
    }

    addAnwerSelection() {

        const cards = this.getCards();

        if (cards.length === null) {
            return;
        }
        cards.forEach(card => this.addListener(card, this.uniqueID));

        this.addMultiSubmitBtn();
    }

    addListener = (card) => {

        var self = this;
        // Update animation of the card entry.
        this.updateAnimation(card);

        card.onclick = e => {
            // Make checked the radion buttons. and add selected class to make the card selected.
            const ratio = e.target.closest('.card').parentNode.querySelector(SELECTORS.answerRadio);
            if (ratio !== null) {
                ratio.click();
                self.flipTheCard(e);
            }
        };

        var ratiobtns = document.querySelectorAll(this.uniqueID + ' ' + SELECTORS.answerRadio);
        var self = this;
        // Attache event listners on the click for answer radio buttons to make the answer submittable.
        ratiobtns === null || ratiobtns.forEach(
            btn => {
                btn.onchange = (e) => self.verifyResponse(e, self);
            }
        );
    };

    updateAnimation(card) {
        var animateElem = card.parentNode;
        animateElem.classList.add(animateElem.dataset.animation || 'no-animation');
        animateElem.style.display = 'block';
        !animateElem.classList.contains('show-feedback') || this.getRoot().classList.add('reveal-feedback');
    }

    verifyResponse(e, self) {
        // Make the clicked card or card related to the clicked radio as selected answer.
        // Remove previous selections.
        e.target.checked
            ? e.target.parentNode.querySelector(SELECTORS.card).classList.add(SELECTORS.other.selectedAnswer)
            : e.target.parentNode.querySelector(SELECTORS.card).classList.remove(SELECTORS.other.selectedAnswer);

        self.options.multianswer || self.submitResults(e);
    }

    submitResults() {

        // Target response form.
        const form = this.responseForm;

        if (form.classList.contains(SELECTORS.other.feedbackListen)) {
            this.disableResponseFormSubmissions();
            return false;
        }
        var self = this;

        var fieldset = this.root.querySelector(SELECTORS.fieldset);
        var prefix = fieldset.dataset.fieldprefix;

        var formdata = new FormData(form);
        var formdataString = new URLSearchParams(formdata).toString();
        var attemptid = new URLSearchParams(formdata).get('attempt');

        form.classList.add(SELECTORS.other.feedbackListen);

        // Adding loading icon to the formulation container before send the promise.
        var spinner = LoadingIcon.addIconToContainerWithPromise(fieldset);

        // If this question in the preview section then submits the form directly.
        if (this.ispreview) {
            if (form.querySelector('.im-controls button.submit') !== null) {
                form.querySelector('.im-controls button.submit').click();
            } else {
                form.submit();
            }
            return true;
        }

        // Disable the response submission until the fragment loads and feedback listened.
        this.disableResponseFormSubmissions();
        this.disableNextButton(); // Disable the next button.

        loadFragment('qtype_imagechoice', 'processattempt', contextID, {formdata: formdataString, prefix: prefix, previewid: this.previewid || ''})
        .then((html, js) => {

            spinner.resolve();
            var question = self.getRoot();

            question.classList.add('reveal-feedback');

            // Convert the ajax response to html node.
            html = new DOMParser().parseFromString(html, 'text/html').body.firstElementChild;
            html.style.display = 'none';

            question.parentNode.insertBefore(html, question);

            // Notifiy the video js plugin to update the audios.
            FilterEvents.notifyFilterContentUpdated(self.getRoot());

            var imgs = document.querySelector(self.uniqueID).querySelectorAll('img');

            // Update the length of the images in the answer text.
            const updateLength = () => {
                // Verify the answer images are loadded.
                var c = 0;
                imgs.forEach((img) => {
                    img.complete ? c++ : '';
                    if (c == imgs.length) {
                        question.remove();
                        document.querySelector(self.uniqueID).style.display = 'block';
                        // Update the cards animations.
                        Templates.runTemplateJS(js);
                    }
                });
            };


            if (imgs !== null) {
                updateLength(); // Verify all the images are loadded.
                imgs.forEach((img) => {
                    // On the answer image loadded verify the length.
                    img.onload = () => updateLength();
                });
            }

            self.getRoot().classList.add('feedback-force-listen');
            if (self.getRoot().querySelector('.feedback-info') !== null) {
                self.getRoot().querySelector('.feedback-info').style.visibility = 'visible';
            }

            self.enableFeedback();

            self.updateQuizNavigation(self.contextID, attemptid);

        }).catch(Notification.exception);

    }

    disableNextButton() {

        const responseForm = this.responseForm;

        if (this.options.forcenext == 0) {
            responseForm.querySelectorAll(SELECTORS.nextButton).forEach(e => {
                e.disabled = true;
            });
        } else {
            responseForm.querySelectorAll(SELECTORS.nextButton).forEach(e => {
                e.style.visibility = 'hidden';
            });
        }
    }

    enableFeedback() {

        const responseForm = this.responseForm;
        const self = this;

        const enableNextButton = () => {

            if (self.options.forcenext == 0) {
                responseForm.querySelectorAll(SELECTORS.nextButton).forEach(e => {
                    e.disabled = false;
                });
            } else {
                console.log('enable button');
                responseForm.querySelectorAll(SELECTORS.nextButton).forEach(e => {
                    e.style.visibility = 'visible';
                });
            }

            // Hide the feedback instruction, listen to continue.
            if (this.getRoot().querySelector('.feedback-info') !== null) {
                this.getRoot().querySelector('.feedback-info').style.visibility = 'hidden';
            }

            // Remove the feedback listen class from response form to continue the form submissions.
            responseForm.classList.remove(SELECTORS.other.feedbackListen);

            self.getRoot().classList.remove('feedback-force-listen');

            // Continue the timer again.
            if (M.mod_quiz.timer.Y !== null) {
                M.mod_quiz.timer.update();
            }
            // This will fix the yui clear next name when submission from quiz navigation panel.
            responseForm.querySelector('input[type="submit"].mod_quiz-next-nav') === null
                || responseForm.querySelector('input[type="submit"].mod_quiz-next-nav').setAttribute('name', 'next');
        };

        // Enable the submit buttons to access the next pages.
        if (self.options.forcefeedback === forceFeedback.none) {
            enableNextButton();
        }

        // If is audio, then force the users to watch all the audio in the responses.
        if (self.options.forcefeedback === forceFeedback.audio) {

            const audios = self.getRoot().querySelectorAll(SELECTORS.feedbackAudio);

            let currentAudioIndex = 0;

            const confirmAudioCompletes = () => {
                var pendingAudio = 0;
                audios.forEach(audio => audio.ended || pendingAudio++);
                return pendingAudio == 0;
            };

            const playNextAudio = () => {
                if (currentAudioIndex < audios.length) {
                    audios[currentAudioIndex].play();
                }
            };

            if (audios.length > 0) {
                var i = 0;
                audios.forEach(audio => {
                    audio.onended = () => {
                        // Verify all the audios are completed.
                        if (confirmAudioCompletes()) {
                            enableNextButton(); // Enable the next button to proceed with attempt.
                        } else {
                            currentAudioIndex++;
                            playNextAudio();
                        }
                    }
                    if (!i) {
                        // Timeout to make the audio skil respond the audio play/pause icons.
                        setTimeout(() => audio.play(), 10);
                    }
                    i++;
                });
            } else {
                enableNextButton();
            }

        }

        if (self.options.forcefeedback === forceFeedback.duration) {
            // Feedback Text.
            const feedbackText = responseForm.querySelector(SELECTORS.feedbackText);

            if (feedbackText !== null && feedbackText.text !== '') {

                setTimeout(enableNextButton, Math.floor(self.options.feedbackduration * 1000));
            }
        }
    }

    disableResponseFormSubmissions() {

        // Prevent the submission of the next button untill the question is answered.
        const responseForm = this.getResponseForm();

        if (responseForm === null) {
            return;
        }

        /* if (responseForm.querySelector('.que.notyetanswered') !== null) {
            responseForm.querySelectorAll('.submitbtns .btn').forEach(btn => {
                btn.onclick = (e) => responseForm.querySelector('.que.notyetanswered') === null || e.preventDefault();
            });
        } */

        // During the force the learner to listen the feedback prevent form submissions.
        responseForm.onsubmit = (e) => {
            if (e.target.classList.contains(SELECTORS.other.feedbackListen)) {
                e.preventDefault();
            }
        }
    }

    addMultiSubmitBtn() {
        const submitBtn = this.getRoot().querySelector(SELECTORS.multiAnswerSubmit);

        if (submitBtn === null) {
            return;
        }

        var self = this;
        submitBtn.onclick = function(e) {
            e.preventDefault();
            if (self.getRoot().querySelector(SELECTORS.answerRadio + ":checked") !== null) {
                self.submitResults(e);
            } else {
                self.showError();
            }
        };
    }

    /**
     * Flip the card during the review.
     *
     * @param {Event} e
     */
    flipTheCard(e) {

        console.log(e.target);
        if (!e.currentTarget.classList.contains('card')
            || e.target.classList.contains('specificfeedback')
            || e.target.closest('.specificfeedback')) {
            return;
        }
        var card = e.target.closest('.card');
        if (this.getRoot().classList.contains('reveal-feedback')) {
            var animateElem = card.parentNode;
            animateElem.classList.remove('animate__flipInY')
            setTimeout(() => {
                card.parentNode.classList.toggle('show-feedback');
                animateElem.classList.add('animate__flipInY')
            }, 2);
        }
    }

    updateQuizNavigation(contextID, attemptID, noPage = null) {
        loadFragment('qtype_imagechoice', 'update_review_navigation', contextID, {attempt: attemptID, nopage: noPage}).then((html, js) => {
            Templates.replaceNodeContents('#mod_quiz_navblock .content', html, js);
        }).catch(Notification.exception);
    }
}

export default {

    init: (questionDivID, contextid, option) => {
        console.log(questionDivID);
        console.log(option);
        new ImageChoiceQuestionType(questionDivID, contextid, option);
    },
};
