<?php

/**
 * Defines the manage license form for the image choice question type.
 *
 * @package    qtype_imagechoice
 * @copyright  2024 LMSACE <lmsace.com>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

require_once("$CFG->libdir/formslib.php");

/**
 * NCT plugins - manage license form.
 */
class license_form extends \moodleform {

    /**
     * License elements defined.
     *
     * @return void
     */
    public function definition() {
        $mform = $this->_form;

        // License key.
        $mform->addElement('text', 'license_key', get_string('licensekey', 'qtype_imagechoice'));
        $mform->setType('license_key', PARAM_TEXT);
        $mform->addRule('license_key', null, 'required', null, 'client');

        // Display the license status.
        $mform->addElement('text', 'license_status', 'License status', '', ['readonly' => 'readonly']);
        $mform->setDefault('license_status', $this->_customdata['license_status'] ?? '');
        $mform->setType('license_status', PARAM_TEXT);
        $mform->disabledIf('license_status', 'license_disable', 'eq', 1);

        // Disable the license status override by users.
        $mform->addElement('hidden', 'license_disable', 1);
        $mform->setType('license_disable', PARAM_BOOL);

        $mform->addElement('submit', 'activate', get_string('activatelicense', 'qtype_imagechoice'));
        $mform->addElement('submit', 'deactivate', get_string('deactivatelicense', 'qtype_imagechoice'));
    }
}
