<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * DB authentication plugin upgrade code
 *
 * @package    qtype_multiorder
 * @copyright  LMSACE Dev Team
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

/**
 * Function to upgrade qtype_multiorder.
 * @param int $oldversion the version we are upgrading from
 * @return bool result
 */
function xmldb_qtype_multiorder_upgrade($oldversion) {
    global $DB;

    $dbman = $DB->get_manager();

    if ($oldversion < 2024062600) {
        $datasourcetable = new xmldb_table('question_multiorder');
        // Adding fields to table dash_data_source.
        $datasourcetable->add_field('id', XMLDB_TYPE_INTEGER, '10', null, XMLDB_NOTNULL, XMLDB_SEQUENCE, null);
        $datasourcetable->add_field('questionid', XMLDB_TYPE_INTEGER, '10', null, XMLDB_NOTNULL, null, 0);
        $datasourcetable->add_field('correctfeedback', XMLDB_TYPE_TEXT, null, null, XMLDB_NOTNULL, null, null);
        $datasourcetable->add_field('correctfeedbackformat', XMLDB_TYPE_INTEGER, '4', null, XMLDB_NOTNULL, null, 0);
        $datasourcetable->add_field('partiallycorrectfeedback', XMLDB_TYPE_TEXT, null, null, XMLDB_NOTNULL, null, null);
        $datasourcetable->add_field('partiallycorrectfeedbackformat', XMLDB_TYPE_INTEGER, '4', null, XMLDB_NOTNULL, null, 0);
        $datasourcetable->add_field('incorrectfeedback', XMLDB_TYPE_TEXT, null, null, XMLDB_NOTNULL, null, null);
        $datasourcetable->add_field('incorrectfeedbackformat', XMLDB_TYPE_INTEGER, '4', null, XMLDB_NOTNULL, null, 0);
        $datasourcetable->add_field('shownumcorrect', XMLDB_TYPE_INTEGER, '2', null, XMLDB_NOTNULL, null, 0);
        // Adding keys to table dash_data_source.
        $datasourcetable->add_key('primary', XMLDB_KEY_PRIMARY, ['id']);
        $datasourcetable->add_key('foreign', XMLDB_KEY_FOREIGN, ['questionid']);

        // Conditionally launch create table for dash_data_source.
        if (!$dbman->table_exists($datasourcetable)) {
            $dbman->create_table($datasourcetable);
        }
        // Dash savepoint reached.
        upgrade_plugin_savepoint(true, 2024062600, 'qtype', 'multiorder');
    }

    if ($oldversion < 2024081201) {
        $datasourcetable = new xmldb_table('question_multiorder_groups');
        // Adding fields to table dash_data_source.
        $datasourcetable->add_field('id', XMLDB_TYPE_INTEGER, '10', null, XMLDB_NOTNULL, XMLDB_SEQUENCE, null);
        $datasourcetable->add_field('questionid', XMLDB_TYPE_INTEGER, '10', null, XMLDB_NOTNULL, null, 0);
        $datasourcetable->add_field('groupid', XMLDB_TYPE_INTEGER, '10', null, XMLDB_NOTNULL, null, 0);
        $datasourcetable->add_field('name', XMLDB_TYPE_CHAR, '255', null, XMLDB_NOTNULL, null, null);
        $datasourcetable->add_field('selectoption', XMLDB_TYPE_INTEGER, '10', null, XMLDB_NOTNULL, null, 0);
        $datasourcetable->add_field('timecreated', XMLDB_TYPE_INTEGER, '11', null, XMLDB_NOTNULL, null, null);
        $datasourcetable->add_field('timemodified', XMLDB_TYPE_INTEGER, '11', null, null, null, null);
        // Adding keys to table dash_data_source.
        $datasourcetable->add_key('primary', XMLDB_KEY_PRIMARY, ['id']);
        $datasourcetable->add_key('foreign', XMLDB_KEY_FOREIGN, ['questionid']);

        // Conditionally launch create table for dash_data_source.
        if (!$dbman->table_exists($datasourcetable)) {
            $dbman->create_table($datasourcetable);
        }
        // Dash savepoint reached.
        upgrade_plugin_savepoint(true, 2024081201, 'qtype', 'multiorder');
    }

    return true;

}