# LMSACE Reports

LMSACE Reports is a Moodle plugin designed to provide comprehensive overview reports for Moodle sites. With LMSACE Reports, administrators, students, and teachers can gain valuable insights into site-wide, course-specific, and user progress data, enabling them to make informed decisions and improve the e-learning experience.

## Key Features:

  1. **Site-wide Reports**: Gain insights into overall site performance, including user registrations, course enrollments, and site-wide activities.
  2. **Course Reports**: Monitor course-specific metrics such as enrollment trends, user activity, and course completion rates.
  3. **User Progress Reports**: Track individual user progress, quiz results, assignment submissions, and more to identify areas for improvement and intervention.

## Benefits

  * **Administrators**: Gain a holistic view of your Moodle site's performance and make data-driven decisions to enhance the e-learning experience.
  * **Students**: Monitor your own progress and identify areas for improvement to optimize your learning journey.
  * **Teachers**: Evaluate course effectiveness, track student engagement, and tailor courses to better meet the needs of your students.


## Getting Started:

### Installation:

Install the lmsace report like any other reports to folder
/report/lmsace

See http://docs.moodle.org/en/Installing_plugins for details on installing Moodle plugins

### Configuration:

Customize the plugin settings to adjust report parameters and permissions to fit your organization's needs.

To enable or disable specific reports:

1. Navigate to Site administration > Plugins > Reports > LMSACE Reports.
2. Enable or disable any reports you wish to hide or show to users.
3. Click the "Save Changes" button to apply your settings.

### Accessing Reports:

Access LMSACE Reports from the Moodle navigation menu to view site-wide, course, and user progress reports.

1. Go to Site administration > Reports > LMSACE Reports.
2. On the report page, you'll see three tabs: Site Reports, Course Reports, and User Reports. Click on the tab you need to access the relevant reports.

    * In the course reports section, you'll find a course selector. This tool allows you to choose the specific course for which you want to view reports.
    * Similarly, in the user reports section, you'll find a user selector. You can use this feature to generate a report for any particular user.
    * By default, both reports are generated for the first entry unless you specify otherwise using the selectors.


#### Accessing Course Reports from Course Administration:

Teachers and managers can access course reports from the course administration section.

1. Navigate to the desired course.
2. Click on the "Reports" menu in the secondary course navigation.
3. Select the "LMSACE Course Reports" link to access the reports specific to that course.


#### Accessing User Reports from User Profile Page:

Users or individuals with the capability to view other users' profiles can access the user report from the user profile page.

1. Navigate to the user profile for which you want to generate the report.
2. In the profile page, locate the "Reports" category.
3. Click on "LMSACE User Reports" to access the report for that user.


### Usage

#### Site Reports

1. **Site Performance Overview:**
   Display key metrics for site-wide performance, including:
   - Total site-wide enrolments
   - Activity completions
   - Course completions
   - New registrations
   - Number of site visits

2. **Site Basic Information:**
   Display key metrics for site-wide basic informations, including:
   - Addtional plugins installed
   - Moodle source directory size
   - Moodle data directory size

3. **User Registration Info:**
   Access detailed information on user registrations, including:
   - Number of users registered
   - Number of deleted users
   - Number of confirmed users
   - Number of unconfirmed users

4. **Registered User Enrolment Stats:**
   Monitor registered user enrolment statistics, such as:
   - Number of users not enrolled in any course
   - Number of users who haven't accessed the site in the last 7 days
   - Number of users enrolled in more than one course

5. **Top 10 Courses by Enrolment:**
   Identify the top 10 most popular courses based on enrolment numbers.

6. **Top 10 Courses by Completion:**
   Track course completion rates to identify the top-performing courses.

6. **Site User Visits:**
   View user visit statistics, including:
   - Number of users visiting the site
   - Number of visits to courses
   - Number of modules visited by users

#### Course Reports

1. **Course Modules & Grades**
    Monitor student performance across course modules and assignments.

2. **Active & Inactive Users by Month:**
   Track user engagement over time, distinguishing between active and inactive users.
   - Number of active users and inactive users grouped by month.

3. **Course Users Activity:**
   Analyze user activity within specific courses, categorizing users based on their progress.
   - Users categorized as not yet started, in-progress, enrolled, or completed.

4. **Course Visits by Users:**
   View user visit data to understand user interactions with course content.
   - Number of visits by users for this course.

5. **High Scores in Course:**
   Identify top-performing students based on quiz and assignment scores.
   - Display the top 20 highest-scoring users in the course.

#### User Reports

1. **My Activities:**
   Review a summary of personal learning activities, including resource views and forum participation.
   - Number of activities
   - Number of completed activities
   - Number of overdue activities

2. **My Quizzes & Assignments:**
   Access quiz and assignment results and performance metrics for completed courses.
   - Number of quizzes
   - Number of completed quizzes
   - Number of quiz attempts
   - Number of assignments
   - Number of completed assignments
   - Number of assignment submissions

3. **Cohorts & Groups:**
   Manage cohort memberships and group assignments efficiently.
   - Number of cohorts
   - Number of groups the user is added to

4. **User Logins & Scores:**
   Track login activity to assess user engagement and participation levels.
   - Number of user logins
   - Scores in enrolled courses

5. **10 Most Visited Courses:**
   Identify frequently accessed courses to prioritize learning efforts.
   - Top 10 courses most visited by this user

## Conclusion:

LMSACE Reports is a powerful tool that provides valuable insights into your Moodle site's performance. Whether you're an administrator, student, or teacher, LMSACE Reports empowers you to optimize the e-learning experience and achieve better outcomes.
