<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Home page slider adminstration settings for enlight theme.
 *
 * @package    theme_enlight
 * @copyright  2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @authors    LMSACE Dev Team
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

    // Home page slider settings.
    $temp = new admin_settingpage('theme_enlight_slideshow', get_string('slideshowheading', 'theme_enlight'));
    $temp->add(new admin_setting_heading('theme_enlight_slideshow', get_string('slideshowheadingsub', 'theme_enlight'),
    format_text(get_string('slideshowdesc', 'theme_enlight'), FORMAT_MARKDOWN)));

    // Number of slides.
    $name = 'theme_enlight/numberofslides';
    $title = get_string('numberofslides', 'theme_enlight');
    $description = get_string('numberofslidesdesc', 'theme_enlight');
    $default = 1;
    $choices = array(
        1 => '1',
        2 => '2',
        3 => '3',
        4 => '4',
        5 => '5',
        6 => '6',
        7 => '7',
        8 => '8',
        9 => '9',
        10 => '10',
        11 => '11',
        12 => '12',
    );
    $temp->add(new admin_setting_configselect($name, $title, $description, $default, $choices));

    // SlideShow Status
    $name = 'theme_enlight/slideshowStatus';
    $title = get_string('slideshowStatus', 'theme_enlight');
    $description = get_string('slideshowStatus_desc', 'theme_enlight');
    $yes = get_string('yes');
    $no = get_string('no' );
    $default = 1;
    $choices = array(1 => $yes , 0 => $no);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $temp->add($setting);
    // Auto Scroll.
    $name = 'theme_enlight/autoslideshow';
    $title = get_string('autoslideshow', 'theme_enlight');
    $description = get_string('autoslideshowdesc', 'theme_enlight');
    $yes = get_string('yes');
    $no = get_string('no');
    $default = 1;
    $choices = array(1 => $yes , 0 => $no);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $temp->add($setting);

    // Auto Scroll.
    $name = 'theme_enlight/slideshowpagination';
    $title = get_string('pagination', 'theme_enlight');
    $description = get_string('pagination_desc', 'theme_enlight');
    $dot = get_string('dots', 'theme_enlight');
    $dotThumb = get_string('dotThumb', 'theme_enlight');
    $thumb = get_string('thumbnails', 'theme_enlight');
    $none = get_string('pagi_none', 'theme_enlight');
    $default = "DOT";
    $choices = array( "DOTTHUMB" => $dotThumb, "THUMB" => $thumb, "DOT" => $dot, "NONE" => $none);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $temp->add($setting);

    // Slide Show Interval.
    $name = 'theme_enlight/slideinterval';
    $title = get_string('slideinterval', 'theme_enlight');
    $description = get_string('slideintervaldesc', 'theme_enlight');
    $default = 3500;
    $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_INT);
    $temp->add($setting);

    // Slideshow height.
    $name = 'theme_enlight/slideHeight';
    $title = get_string('slideheight', 'theme_enlight');
    $description = get_string('slideheight_desc', 'theme_enlight');
    $default = '550';
    $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
    $temp->add($setting);

    // Slide Overlay Opacity.
    $name = 'theme_enlight/slideOverlay_opacity';
    $title = get_string('slideOverlay', 'theme_enlight');
    $description = get_string('slideOverlay_desc', 'theme_enlight');
    $opacity = array();
    $opacity = array_combine(range(0, 1, 0.1 ), range(0, 1, 0.1 ));
    $setting = new admin_setting_configselect($name, $title, $description, '0.4', $opacity);
    $setting->set_updatedcallback('theme_reset_all_caches');
    $temp->add($setting);
    $animations = array(
        "NONE" => get_string('none', 'theme_enlight'),
        "flash" => get_string('flash', 'theme_enlight'),
        "bounceIn" => get_string('bounceIn', 'theme_enlight'),
        "bounceInDown" => get_string('bounceInDown', 'theme_enlight'),
        "bounceInLeft" => get_string('bounceInLeft', 'theme_enlight'),
        "bounceInRight" => get_string('bounceInRight', 'theme_enlight'),
        "bounceInUp" => get_string('bounceInUp', 'theme_enlight'),
        "fadeIn" => get_string('fadeIn', 'theme_enlight'),
        "fadeInDown" => get_string('fadeInDown', 'theme_enlight'),
        "fadeInDownBig" => get_string('fadeInDownBig', 'theme_enlight'),
        "fadeInLeft" => get_string('fadeInLeft', 'theme_enlight'),
        "fadeInLeftBig" => get_string('fadeInLeftBig', 'theme_enlight'),
        "fadeInRight" => get_string('fadeInRight', 'theme_enlight'),
        "fadeInRightBig" => get_string('fadeInRightBig', 'theme_enlight'),
        "fadeInUp" => get_string('fadeInUp', 'theme_enlight'),
        "fadeInUpBig" => get_string('fadeInUpBig', 'theme_enlight'),
        "fadeOut" => get_string('fadeOut', 'theme_enlight'),
        "flip" => get_string('flip', 'theme_enlight'),
        "flipInX" => get_string('flipInX', 'theme_enlight'),
        "flipInY" => get_string('flipInY', 'theme_enlight'),
        "flipOutX" => get_string('flipOutX', 'theme_enlight'),
        "flipOutY" => get_string('flipOutY', 'theme_enlight'),
        "lightSpeedIn" => get_string('lightSpeedIn', 'theme_enlight'),
        "rotateIn" => get_string('rotateIn', 'theme_enlight'),
        "rotateInDownLeft" => get_string('rotateInDownLeft', 'theme_enlight'),
        "rotateInDownRight" => get_string('rotateInDownRight', 'theme_enlight'),
        "rotateInUpLeft" => get_string('rotateInUpLeft', 'theme_enlight'),
        "rotateInUpRight" => get_string('rotateInUpRight', 'theme_enlight'),
        "slideInUp" => get_string('slideInUp', 'theme_enlight'),
        "slideInDown" => get_string('slideInDown', 'theme_enlight'),
        "slideInLeft" => get_string('slideInLeft', 'theme_enlight'),
        "slideInRight" => get_string('slideInRight', 'theme_enlight'),
        "zoomIn" => get_string('zoom-In', 'theme_enlight'),
        "zoomInDown" => get_string('zoomInDown', 'theme_enlight'),
        "zoomInLeft" => get_string('zoomInLeft', 'theme_enlight'),
        "zoomInRight" => get_string('zoomInRight', 'theme_enlight'),
        "zoomInUp" => get_string('zoomInUp', 'theme_enlight'),
        "hinge" => get_string('hinge', 'theme_enlight'),
        "rollIn" => get_string('rollIn', 'theme_enlight'),
    );

    $effects = array(
        "scrollRight" => get_string('none', 'theme_enlight'),
        'random' => get_string('random', 'theme_enlight'),
        'simpleFade' => get_string('simpleFade', 'theme_enlight'),
        'curtainTopLeft' => get_string('curtainTopLeft', 'theme_enlight'),
        'curtainTopRight' => get_string('curtainTopRight', 'theme_enlight'),
        'curtainBottomLeft' => get_string('curtainBottomLeft', 'theme_enlight'),
        'curtainBottomRight' => get_string('curtainBottomRight', 'theme_enlight'),
        'curtainSliceLeft' => get_string('curtainSliceLeft', 'theme_enlight'),
        'curtainSliceRight' => get_string('curtainSliceRight', 'theme_enlight'),
        'blindCurtainTopLeft' => get_string('blindCurtainTopLeft', 'theme_enlight'),
        'blindCurtainTopRight' => get_string('blindCurtainTopRight', 'theme_enlight'),
        'blindCurtainBottomLeft' => get_string('blindCurtainBottomLeft', 'theme_enlight'),
        'blindCurtainBottomRight' => get_string('blindCurtainBottomRight', 'theme_enlight'),
        'blindCurtainSliceBottom' => get_string('blindCurtainSliceBottom', 'theme_enlight'),
        'blindCurtainSliceTop' => get_string('blindCurtainSliceTop', 'theme_enlight'),
        'stampede' => get_string('stampede', 'theme_enlight'),
        'mosaic' => get_string('mosaic', 'theme_enlight'),
        'mosaicReverse' => get_string('mosaicReverse', 'theme_enlight'),
        'mosaicRandom' => get_string('mosaicRandom', 'theme_enlight'),
        'mosaicSpiral' => get_string('mosaicSpiral', 'theme_enlight'),
        'mosaicSpiralReverse' => get_string('mosaicSpiralReverse', 'theme_enlight'),
        'topLeftBottomRight' => get_string('topLeftBottomRight', 'theme_enlight'),
        'bottomRightTopLeft' => get_string('bottomRightTopLeft', 'theme_enlight'),
        'bottomLeftTopRight' => get_string('bottomLeftTopRight', 'theme_enlight'),
        'bottomLeftTopRight' => get_string('bottomLeftTopRight', 'theme_enlight'),
        'scrollLeft' => get_string('scrollLeft', 'theme_enlight'),
        'scrollRight' => get_string('scrollRight', 'theme_enlight'),
        'scrollHorz' => get_string('scrollHorz', 'theme_enlight'),
        'scrollBottom' => get_string('scrollBottom', 'theme_enlight'),
        'scrollTop' => get_string('scrollTop', 'theme_enlight'),

        );

    $numberofslides = get_config('theme_enlight', 'numberofslides');
    for ($i = 1; $i <= $numberofslides; $i++) {

        // This is the descriptor for Slide One.
        $name = 'theme_enlight/slide' . $i . 'info';
        $heading = get_string('slideno', 'theme_enlight', array('slide' => $i));
        $information = "";
        $setting = new admin_setting_heading($name, $heading, $information);
        $temp->add($setting);

        // SlideShow Status
        $name = 'theme_enlight/slide'.$i.'status';
        $title = get_string('slideStatus', 'theme_enlight', array('slide' => $i));
        $description = get_string('slideStatus_desc', 'theme_enlight', array('slide' => $i));
        $yes = get_string('enable', 'theme_enlight');
        $no = get_string('disable', 'theme_enlight');
        $default = 1;
        $choices = array(1 => $yes , 0 => $no);
        $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
        $temp->add($setting);

        // Slide type video or host.
        $name = 'theme_enlight/slide'. $i.'type';
        $title = get_string('slidetypetitle', 'theme_enlight', array('slide' => $i));
        $description = get_string('slidetypedesc', 'theme_enlight');
        $default = 3;
        $choice = array(
                '2' => get_string('bannerhosted', 'theme_enlight'),
                '3' => get_string('bannerimagebanner', 'theme_enlight'),
            );
        $setting = new admin_setting_configselect($name, $title, $description, $default, $choice);
        $temp->add($setting);

        // Slide Image.
        $name = 'theme_enlight/slide' . $i . 'image';
        $title = get_string('slideimage', 'theme_enlight', array('slide' => $i));
        $description = get_string('slideimagedesc', 'theme_enlight');
        $setting = new admin_setting_configstoredfile($name, $title, $description, 'slide' . $i . 'image');
        $setting->set_updatedcallback('theme_reset_all_caches');
        $temp->add($setting);

         // Video URL.
         $name = 'theme_enlight/slide'. $i. 'videourl';
         $title = get_string('bannervideourl', 'theme_enlight', array('slide' => $i));
         $description = get_string('bannervideourldesc', 'theme_enlight');
         $default = 'http://res.cloudinary.com/lmsace/video/upload/v1502450231/Children.mp4';
         $setting = new admin_setting_configtext($name, $title, $description, $default);
         $temp->add($setting);

        // Slide Caption.
        $name = 'theme_enlight/slide' . $i . 'caption';
        $title = get_string('slidecaption', 'theme_enlight', array('slide' => $i));
        $description = get_string('slidecaptiondesc', 'theme_enlight');
        $default = 'lang:slidecaptiondefault';
        $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
        $temp->add($setting);

        // Slide Description Text.
        $name = 'theme_enlight/slide' . $i . 'desc';
        $title = get_string('slidedesc', 'theme_enlight', array('slide' => $i));
        $description = get_string('slidedesctext', 'theme_enlight');
        $default = 'lang:slidedescdefault';
        $setting = new admin_setting_configtextarea($name, $title, $description, $default, PARAM_TEXT);
        $temp->add($setting);

        // Slide Link text.
        $name = 'theme_enlight/slide' . $i . 'urltext1';
        $title = get_string('slideurl1text', 'theme_enlight', array('type' => "1"));
        $description = get_string('slideurl1textdesc', 'theme_enlight');
        $default = 'lang:knowmore';
        $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
        $temp->add($setting);

        // Slide Url.
        $name = 'theme_enlight/slide' . $i . 'url1';
        $title = get_string('slideurl1', 'theme_enlight', array('type' => "1"));
        $description = get_string('slideurl1desc', 'theme_enlight');
        $default = 'http://www.example.com/';
        $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_URL);
        $temp->add($setting);

        $name = 'theme_enlight/slide'.$i.'urltarget1';
        $title = get_string('urltarget1', 'theme_enlight', array('type' => "1"));
        $description = get_string('urltarget_desc', 'theme_enlight', array('slide' => $i));
        $same = get_string('sameWindow', 'theme_enlight');
        $new = get_string('newWindow', 'theme_enlight');
        $default = 1;
        $choices = array(0 => $same , 1 => $new);
        $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
        $temp->add($setting);

        // Slide Link text.
        $name = 'theme_enlight/slide' . $i . 'urltext2';
        $title = get_string('slideurl2text', 'theme_enlight', array('type' => "2"));
        $description = get_string('slideurl2textdesc', 'theme_enlight');
        $default = 'lang:knowmore';
        $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
        $temp->add($setting);

        // Slide Url.
        $name = 'theme_enlight/slide' . $i . 'url2';
        $title = get_string('slideurl2', 'theme_enlight', array('type' => "2"));
        $description = get_string('slideurl2desc', 'theme_enlight');
        $default = 'http://www.example.com/';
        $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_URL);
        $temp->add($setting);

        $name = 'theme_enlight/slide'.$i.'urltarget2';
        $title = get_string('urltarget2', 'theme_enlight', array('type' => "2"));
        $description = get_string('urltarget_desc', 'theme_enlight', array('slide' => $i));
        $same = get_string('sameWindow', 'theme_enlight');
        $new = get_string('newWindow', 'theme_enlight');
        $default = 1;
        $choices = array(0 => $same , 1 => $new);
        $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
        $temp->add($setting);

        $name = 'theme_enlight/slide' . $i . 'contFullwidth';
        $title = get_string('slideCont_full', 'theme_enlight');
        $description = get_string('slideCont_fulldesc', 'theme_enlight');
        $default = "50";
        $setting = new admin_setting_configtext($name, $title, $description, $default);
        $setting->set_updatedcallback('theme_reset_all_caches');
        $temp->add($setting);

        $name = 'theme_enlight/slide'. $i .'contentStyle';
        $title = get_string('slideContentStyle', 'theme_enlight');
        $description = get_string('slideContentStyle_desc', 'theme_enlight');

        $contentOverlay = get_string('contentOverlay', 'theme_enlight');
        $sliderOverlay = get_string('sliderOverlay', 'theme_enlight');
        $doubleHeading = get_string('doubleHeading', 'theme_enlight');
        $themebased = get_string('themebased', 'theme_enlight');

        $default = 2;
        $choices = array( 2 => $contentOverlay, 4 => $sliderOverlay, 3 => $doubleHeading, 1 => $themebased);
        $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
        $temp->add($setting);

         // Slider content position.
        $name = 'theme_enlight/slide' . $i . 'contentPosition';
        $title = get_string('slidecontent', 'theme_enlight', array('slide' => $i));
        $description = get_string('slidecontentdesc', 'theme_enlight');

        $topLeft = get_string("topLeft", "theme_enlight");
        $topCenter = get_string("topCenter", "theme_enlight");
        $topRight = get_string("topRight", "theme_enlight");
        $centerLeft = get_string("centerLeft", "theme_enlight");
        $center = get_string("center", "theme_enlight");
        $centerRight = get_string("centerRight", "theme_enlight");
        $bottomLeft = get_string("bottomLeft", "theme_enlight");
        $bottomCenter = get_string("bottomCenter", "theme_enlight");
        $bottomRight = get_string("bottomRight", "theme_enlight");

        $default = 'centerRight';
        $choicesD = array(
            "topLeft" => $topLeft,
            "topCenter" => $topCenter,
            "topRight" => $topRight,
            "centerLeft" => $centerLeft,
            "center" => $center,
            "centerRight" => $centerRight,
            "bottomLeft" => $bottomLeft,
            "bottomCenter" => $bottomCenter,
            "bottomRight" => $bottomRight,
            );

        $setting = new admin_setting_configselect($name, $title, $description, $default, $choicesD);
        $temp->add($setting);

        $name = 'theme_enlight/slide' . $i . 'contentAnimation';
        $title = get_string('contentAnimate', 'theme_enlight', array('slide' => $i));
        $description = get_string('contentAnimatedesc', 'theme_enlight');
        $default = 'fadeInLeft';
        $setting = new admin_setting_configselect($name, $title, $description, $default, $animations);
        $temp->add($setting);

        $name = 'theme_enlight/slide' . $i . 'effect';
        $title = get_string('slideEffect', 'theme_enlight', array('slide' => $i));
        $description = get_string('slideEffectdesc', 'theme_enlight');
        $default = 'random';
        $setting = new admin_setting_configselect($name, $title, $description, $default, $effects);
        $temp->add($setting);

    }
    $settings->add($temp);
