<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Testimonial adminstration settings for enlight theme.
 *
 * @package    theme_enlight
 * @copyright  2015 onwards LMSACE Dev Team (http://www.lmsace.com)
 * @authors    LMSACE Dev Team
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

    // Testimonial settings.
    $temp = new admin_settingpage('theme_enlight_tmonialhead', get_string('tmonialheading', 'theme_enlight'));

    $name = 'theme_enlight_testimonials';
    $heading = get_string('testiGeneral', 'theme_enlight');
    $information = get_string('tmonialheadingsub_desc', 'theme_enlight');
    $setting = new admin_setting_heading($name, $heading, $information);
    $temp->add($setting);

    // Display Slideshow.
    $name = 'theme_enlight/toggletmonial';
    $title = get_string('toggletmonial', 'theme_enlight');
    $description = get_string('toggletmonialdesc', 'theme_enlight');
    $default = 1;
    $setting = new admin_setting_configcheckbox($name, $title, $description, $default);
    $temp->add($setting);

    //  testimonials title.
    $name = "theme_enlight/testimonialtitle";
    $title = get_string('title', 'theme_enlight');
    $description = get_string('testimonialtitle_desc', 'theme_enlight');
    $default = get_string('testimonial_default', 'theme_enlight');
    $setting = new admin_setting_configtext($name, $title, $description, $default);
    $temp->add($setting);

    $name = 'theme_enlight/tmonialTraversal_status';
    $title = get_string('tmonialTraversal_status', 'theme_enlight');
    $description = get_string('tmonialTraversal_statusdesc', 'theme_enlight');
    $yes = get_string('yes');
    $no = get_string('no');
    $default = 1;
    $choices = array(1 => $yes , 0 => $no);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $temp->add($setting);

    // Auto Scroll.
    $name = 'theme_enlight/testimonialAutoplay';
    $title = get_string('testimonialAutoplay', 'theme_enlight');
    $description = get_string('testimonialAutoplay_desc', 'theme_enlight');
    $yes = get_string('yes');
    $no = get_string('no');
    $default = 1;
    $choices = array(1 => $yes , 0 => $no);
    $setting = new admin_setting_configselect($name, $title, $description, $default, $choices);
    $temp->add($setting);

    $name = 'theme_enlight/numberoftmonials';
    $title = get_string('numberoftmonials', 'theme_enlight');
    $description = get_string('numberoftmonials_desc', 'theme_enlight');
    $default = 1;
    $choices = array(
        1 => '1',
        2 => '2',
        3 => '3',
        4 => '4',
        5 => '5',
        6 => '6',
        7 => '7',
        8 => '8',
        9 => '9',
        10 => '10',
        11 => '11',
        12 => '12',
        13 => '13',
        14 => '14',
        15 => '15',
        16 => '16'
    );
    $temp->add(new admin_setting_configselect($name, $title, $description, $default, $choices));
    // No of testimonials.
    $numberoftmonials = get_config('theme_enlight', 'numberoftmonials');

    for ($i = 1; $i <= $numberoftmonials; $i++) {
        // Testimonial Heading.
        $name = 'theme_enlight/testimonialno' . $i . 'info';
        $heading = get_string('testimonialno', 'theme_enlight', array('tmonial' => $i));
        $information = get_string('testimonialnodesc', 'theme_enlight', array('tmonial' => $i));
        $setting = new admin_setting_heading($name, $heading, $information);
        $temp->add($setting);

        // User Name.
        $name = 'theme_enlight/tmonial' . $i . 'uname';
        $title = get_string('tmonialuname', 'theme_enlight');
        $description = get_string('tmonialunamedesc', 'theme_enlight');
        $default = ($i == 1) ? get_string('tmonialuname_default', 'theme_enlight') : '';
        $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
        $temp->add($setting);

        // Testimonial USER Position.
        $name = 'theme_enlight/tmonial' . $i . 'userposition';
        $title = get_string('tmonialuposition', 'theme_enlight');
        $description = get_string('tmonialupositiondesc', 'theme_enlight');
        $default = '';
        $setting = new admin_setting_configtext($name, $title, $description, $default, PARAM_TEXT);
        $temp->add($setting);

        // Testimonial Image.
        $name = 'theme_enlight/tmonial'. $i . 'img';
        $title = get_string('tmonialimg', 'theme_enlight');
        $description = get_string('tmonialimgdesc', 'theme_enlight');
        $default = 'tmonial'. $i . 'img';
        $setting = new admin_setting_configstoredfile($name , $title, $description, $default);
        $setting->set_updatedcallback('theme_reset_all_caches');
        $temp->add($setting);

        // Testimonial text.
        $name = 'theme_enlight/tmonial' . $i . 'text';
        $title = get_string('tmonialtext', 'theme_enlight');
        $description = get_string('tmonialtextdesc', 'theme_enlight');
        $default = ($i == 1) ? get_string('tmonialtext_default', 'theme_enlight') : '';
        $setting = new admin_setting_configtextarea($name, $title, $description, $default, PARAM_TEXT);
        $temp->add($setting);

    }
    $settings->add($temp);
